/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  autoCorrectedDatePipe,
  dateMask,
  numberMask,
  rangeDateMask
} from "./ids-chunk-L5LKJLMG-full.js";
import {
  CARET_TRAP,
  DEFAULT_CONFORM_OPTIONS,
  EMPTY_STRING,
  PLACEHOLDER_CHAR
} from "./ids-chunk-2GKEPJIA-full.js";
import {
  deepClone
} from "./ids-chunk-G6C62L35-full.js";

// src/components/ids-mask/ids-mask-api.ts
function isString(value) {
  return typeof value === "string" || value instanceof String;
}
var MaskAPI = class {
  /**
   * Process a string against the masking algorithm
   * @param {string} rawValue the original, unmasked value
   * @param {object} [opts] process options
   * @returns {object} containing the processed mask along with some meta-data
   */
  process(rawValue, opts = {}) {
    if (typeof rawValue !== "string") {
      throw new Error("No string provided");
    }
    if (!opts.selection) {
      opts.selection = {
        start: 0
      };
    }
    let maskObj = {};
    let processResult = {
      originalValue: rawValue,
      caretPos: opts?.selection?.start || 0,
      maskResult: false
    };
    if (typeof opts.pattern === "function") {
      if (!opts.patternOptions) {
        opts.patternOptions = {};
      }
      const maskOpts = deepClone(opts.patternOptions);
      maskOpts.caretPos = opts.selection.start;
      maskOpts.previousMaskResult = opts.previousMaskResult;
      maskOpts.locale = opts.locale;
      maskObj = opts.pattern(rawValue, maskOpts);
      if (maskObj?.rawValue && typeof maskObj.rawValue === "string" && maskObj.rawValue !== rawValue) {
        rawValue = maskObj.rawValue;
      }
      if (Array.isArray(maskObj)) {
        maskObj = {
          caretTrapIndexes: [],
          mask: maskObj
        };
      }
      if (Array.isArray(maskObj.mask)) {
        const caretTrapInfo = this.processCaretTraps(maskObj.mask);
        maskObj.mask = caretTrapInfo.maskWithoutCaretTraps;
        maskObj.caretTrapIndexes = caretTrapInfo.indexes;
        opts.caretTrapIndexes = caretTrapInfo.indexes;
      }
    } else {
      maskObj = {
        caretTrapIndexes: [],
        mask: opts.pattern
      };
    }
    try {
      processResult = this.conformToMask(rawValue, maskObj, opts);
    } catch (e) {
      return processResult;
    }
    if (typeof opts.pipe === "function") {
      let pipeResult = {};
      try {
        pipeResult = opts.pipe(processResult, opts);
      } catch (e) {
        pipeResult = false;
      }
      if (pipeResult === false) {
        processResult.pipeResult = false;
        processResult.pipedValue = opts.previousMaskResult;
      } else if (isString(pipeResult)) {
        processResult.pipeResult = true;
        processResult.pipedValue = pipeResult;
        processResult.pipedCharIndexes = [];
      } else {
        processResult = deepClone(processResult);
        processResult.pipeResult = pipeResult.result;
        processResult.pipedValue = pipeResult.value;
        processResult.pipedCharIndexes = pipeResult.characterIndexes;
      }
    }
    return processResult;
  }
  masks = {
    dateMask,
    numberMask,
    rangeDateMask,
    autoCorrectedDatePipe
  };
  /**
   * Processes a raw string value against a masking algorithm and removes unfavorable chracters.
   * @private
   * @param {string} rawValue incoming full text string to process.
   * @param {object} maskObj containing the mask to be used for modifying the raw value,
   *  along with some meta-data calculated about the mask
   * @param {object} [settings] incoming settings for mask parsing.
   * @returns {object} containing the conformation result and some meta-data
   */
  conformToMask(rawValue, maskObj, settings) {
    const conformSettings = deepClone(DEFAULT_CONFORM_OPTIONS);
    Object.assign(conformSettings, settings);
    conformSettings.placeholder = this.convertMaskToPlaceholder(
      maskObj.mask,
      conformSettings.placeholderChar
    );
    let charactersRejected = false;
    const suppressGuide = conformSettings.guide === false;
    const rawValueLength = rawValue.length;
    const prevMaskResultLength = conformSettings.previousMaskResult.length;
    const maskLength = maskObj.mask.length;
    const placeholderLength = conformSettings.placeholder.length;
    const placeholderChar = conformSettings.placeholderChar;
    let caretPos = conformSettings.selection.start;
    let resultStr = EMPTY_STRING;
    const editDistance = rawValueLength - prevMaskResultLength;
    const isAddition = editDistance > 0;
    const indexOfFirstChange = caretPos + (isAddition ? -editDistance : 0);
    const indexOfLastChange = indexOfFirstChange + Math.abs(editDistance);
    if (conformSettings.keepCharacterPositions === true && !isAddition) {
      let compensatingPlaceholderChars = EMPTY_STRING;
      for (let i = indexOfFirstChange; i < indexOfLastChange; i++) {
        if (conformSettings.placeholder[i] === placeholderChar) {
          compensatingPlaceholderChars += placeholderChar;
        }
      }
      rawValue = rawValue.slice(0, indexOfFirstChange) + compensatingPlaceholderChars + rawValue.slice(indexOfFirstChange, rawValueLength);
    }
    function markAddedChars(char, j) {
      return {
        char,
        isNew: j >= indexOfFirstChange && j < indexOfLastChange
      };
    }
    const rawValueArr = rawValue.split(EMPTY_STRING).map(markAddedChars);
    for (let k = rawValueLength - 1; k >= 0; k--) {
      const char = rawValueArr[k];
      if (char !== conformSettings.placeholderChar) {
        const shouldOffset = k >= indexOfFirstChange && prevMaskResultLength === maskLength;
        if (char === conformSettings.placeholder[shouldOffset ? k - editDistance : k]) {
          rawValueArr.splice(k, 1);
        }
      }
    }
    placeholderLoop:
      for (let l = 0; l < placeholderLength; l++) {
        const charInPlaceholder = conformSettings.placeholder[l];
        if (charInPlaceholder === placeholderChar) {
          if (rawValueArr.length > 0) {
            while (rawValueArr.length > 0) {
              const rawValueChar = rawValueArr.shift();
              const nextChar = rawValue.slice(l, l + 1);
              if (rawValueChar.char === placeholderChar && suppressGuide !== true) {
                resultStr += placeholderChar;
                continue placeholderLoop;
              } else if (maskObj.literalRegex && maskObj.literalRegex.test(rawValueChar.char) && nextChar && (nextChar === rawValueChar.char || nextChar === placeholderChar)) {
                if (isAddition && maskObj.literals.indexOf(rawValue[l - 1]) > -1) {
                  caretPos++;
                  continue placeholderLoop;
                }
                const thisLiteralRegex = new RegExp(`(${rawValueChar.char})`, "g");
                const numberLiteralsPlaceholder = conformSettings.placeholder.match(thisLiteralRegex).length;
                const numberLiteralsRawValue = rawValue.match(thisLiteralRegex)?.length;
                if (numberLiteralsRawValue <= numberLiteralsPlaceholder) {
                  resultStr += rawValueChar.char;
                }
                let literalIndex = conformSettings.placeholder.slice(l).indexOf(rawValueChar.char);
                while (literalIndex > 0) {
                  l++;
                  literalIndex--;
                }
                continue placeholderLoop;
              } else if (maskObj.mask[l].test(rawValueChar.char)) {
                if (conformSettings.keepCharacterPositions !== true || rawValueChar.isNew === false || conformSettings.previousMaskResult === EMPTY_STRING || suppressGuide || !isAddition) {
                  resultStr += rawValueChar.char;
                } else {
                  const rawValueArrLength = rawValueArr.length;
                  let indexOfNextAvailablePlaceholderChar = null;
                  for (let x = 0; x < rawValueArrLength; x++) {
                    const charData = rawValueArr[x];
                    if (charData.char !== placeholderChar && charData.isNew === false) {
                      break;
                    }
                    if (charData.char === placeholderChar) {
                      indexOfNextAvailablePlaceholderChar = x;
                      break;
                    }
                  }
                  if (indexOfNextAvailablePlaceholderChar !== null) {
                    resultStr += rawValueChar.char;
                    rawValueArr.splice(indexOfNextAvailablePlaceholderChar, 1);
                  } else {
                    l--;
                  }
                }
                continue placeholderLoop;
              } else {
                charactersRejected = true;
              }
            }
          }
          if (suppressGuide === false) {
            resultStr += conformSettings.placeholder.substr(l, placeholderLength);
          }
          break;
        } else {
          resultStr += charInPlaceholder;
        }
      }
    if (suppressGuide && isAddition === false) {
      let indexOfLastFilledPlaceholderChar = null;
      for (let m = 0; m < resultStr.length; m++) {
        if (conformSettings.placeholder[m] === placeholderChar) {
          indexOfLastFilledPlaceholderChar = m;
        }
      }
      if (indexOfLastFilledPlaceholderChar !== null) {
        resultStr = resultStr.substr(0, indexOfLastFilledPlaceholderChar + 1);
      } else if (rawValue !== "" && resultStr.indexOf(rawValue) > -1) {
        caretPos += rawValue.length;
      } else {
        resultStr = EMPTY_STRING;
      }
    }
    return {
      caretPos,
      caretTrapIndexes: conformSettings.caretTrapIndexes,
      conformedValue: resultStr,
      charactersRejected,
      placeholder: conformSettings.placeholder,
      placeholderChar,
      maskResult: true,
      isPlaceholderMatched: placeholderLength === resultStr.length
    };
  }
  /**
   * Detects Caret Traps inside of a Mask Array and identifies them with a rich object
   * @private
   * @param {Array<string|RegExp>} mask the mask being checked
   * @returns {object} containing a modified Mask array without caret traps, and an array of
   *  indices with locations of the caret traps.
   */
  processCaretTraps(mask) {
    const indexes = [];
    let indexOfCaretTrap = mask.indexOf(CARET_TRAP);
    while (indexOfCaretTrap !== -1) {
      indexes.push(indexOfCaretTrap);
      mask.splice(indexOfCaretTrap, 1);
      indexOfCaretTrap = mask.indexOf(CARET_TRAP);
    }
    return {
      maskWithoutCaretTraps: mask,
      indexes
    };
  }
  /**
   * Converts an array-based mask into a placeholder string.
   * @private
   * @param {Array<string|RegExp>} mask - contains string "literal" characters and Regex matchers.
   * @param {string} placeholderChar - a character that will be used as the placeholder.
   * @returns {string} representing the placeholder
   */
  convertMaskToPlaceholder(mask, placeholderChar = PLACEHOLDER_CHAR) {
    return mask.map((char) => char instanceof RegExp ? placeholderChar : char).join(EMPTY_STRING);
  }
  /**
   * Takes an index representing a caret and changes it based on mask modifications
   * @param {object} opts information about the caret placement.
   * @returns {number} the index of the text caret.
   */
  adjustCaretPosition(opts) {
    if (opts.caretPos === 0) {
      return 0;
    }
    function nonPlaceholderFilter(char) {
      return char !== nonPlaceholderFilter;
    }
    const rawValueLength = opts.rawValue.length;
    const previousConformedValueLength = opts.previousMaskResult.length;
    const placeholderLength = opts.placeholder ? opts.placeholder.length : 0;
    const conformedValueLength = opts.conformedValue ? opts.conformedValue.length : 0;
    const editLength = rawValueLength - previousConformedValueLength;
    const isAddition = editLength > 0;
    const isFirstRawValue = previousConformedValueLength === 0;
    const isPartialMultiCharEdit = editLength > 1 && !isAddition && !isFirstRawValue;
    if (isPartialMultiCharEdit) {
      return opts.caretPos;
    }
    const possiblyHasRejectedChar = isAddition && (opts.previousMaskResult === opts.conformedValue || opts.conformedValue === opts.placeholder);
    let startingSearchIndex = 0;
    let trackRightCharacter;
    let targetChar;
    if (possiblyHasRejectedChar) {
      startingSearchIndex = opts.caretPos - editLength;
    } else {
      const normalizedConformedValue = opts.conformedValue.toLowerCase();
      const normalizedRawValue = opts.rawValue.toLowerCase();
      const leftHalfChars = normalizedRawValue.substr(0, opts.caretPos).split(EMPTY_STRING);
      const intersection = leftHalfChars.filter((char) => normalizedConformedValue.indexOf(char) !== -1);
      targetChar = intersection[intersection.length - 1];
      const previousLeftMaskChars = opts.previousPlaceholder.substr(0, intersection.length).split(EMPTY_STRING).filter(nonPlaceholderFilter).length;
      const leftMaskChars = opts.placeholder.substr(0, intersection.length).split(EMPTY_STRING).filter(nonPlaceholderFilter).length;
      const masklengthChanged = leftMaskChars !== previousLeftMaskChars;
      const targetIsMaskMovingLeft = opts.previousPlaceholder[intersection.length - 1] !== void 0 && opts.placeholder[intersection.length - 2] !== void 0 && opts.previousPlaceholder[intersection.length - 1] !== opts.placeholderChar && opts.previousPlaceholder[intersection.length - 1] !== opts.placeholder[intersection.length - 1] && opts.previousPlaceholder[intersection.length - 1] === opts.placeholder[intersection.length - 2];
      if (!isAddition && (masklengthChanged || targetIsMaskMovingLeft) && previousLeftMaskChars > 0 && opts.placeholder.indexOf(targetChar) > -1 && opts.rawValue[opts.caretPos] !== void 0) {
        trackRightCharacter = true;
        targetChar = opts.rawValue[opts.caretPos];
      }
      let pipedChars = [];
      if (opts.indexesOfPipedChars) {
        pipedChars = opts.indexesOfPipedChars.map((index) => normalizedConformedValue[index]);
      }
      const countTargetCharInPipedChars = pipedChars.filter((char) => char === targetChar).length;
      const countTargetCharInIntersection = intersection.filter((char) => char === targetChar).length;
      const countTargetCharInPlaceholder = opts.placeholder.substr(0, opts.placeholder.indexOf(opts.placeholderChar)).split(EMPTY_STRING).filter((char, index) => char === targetChar && opts.rawValue[index] !== char).length;
      const requiredNumberOfMatches = countTargetCharInPlaceholder + countTargetCharInIntersection + countTargetCharInPipedChars + (trackRightCharacter ? 1 : 0);
      let numberOfEncounteredMatches = 0;
      for (let i = 0; i < conformedValueLength; i++) {
        const conformedValueChar = normalizedConformedValue[i];
        startingSearchIndex = i + 1;
        if (conformedValueChar === targetChar) {
          numberOfEncounteredMatches++;
        }
        if (numberOfEncounteredMatches >= requiredNumberOfMatches) {
          break;
        }
      }
    }
    if (isAddition) {
      let lastPlaceholderChar = startingSearchIndex;
      for (let j = startingSearchIndex; j <= placeholderLength; j++) {
        if (!opts.placeholder) {
          return lastPlaceholderChar;
        }
        if (opts.placeholder[j] === opts.placeholderChar) {
          lastPlaceholderChar = j;
        }
        if (
          // If we're adding, we can position the caret at the next placeholder character.
          opts.placeholder[j] === opts.placeholderChar || opts.caretTrapIndexes.indexOf(j) !== -1 || j === placeholderLength
        ) {
          return lastPlaceholderChar;
        }
      }
    } else {
      if (trackRightCharacter) {
        for (let k = startingSearchIndex - 1; k >= 0; k--) {
          if (
            // `targetChar` should be in `conformedValue`, since it was in `rawValue`, just
            // to the right of the caret
            opts.conformedValue[k] === targetChar || opts.caretTrapIndexes.indexOf(k) !== -1 || k === 0
          ) {
            return k;
          }
        }
      } else {
        for (let l = startingSearchIndex; l >= 0; l--) {
          if (
            // If we're deleting, we can position the caret right before the placeholder character
            opts.placeholder[l - 1] === opts.placeholderChar || opts.caretTrapIndexes.indexOf(l) !== -1 || l === 0
          ) {
            return l;
          }
        }
      }
    }
    return 0;
  }
  /**
   * Gets the safe raw value of an input field
   * @param {any} inputValue the original value that came from an input field or other source
   * @returns {string} the string-ified version of the original value
   */
  getSafeRawValue(inputValue) {
    if (typeof inputValue === "string") {
      return inputValue;
    }
    if (typeof inputValue === "number") {
      return String(inputValue);
    }
    return "";
  }
};
var ids_mask_api_default = MaskAPI;

export {
  ids_mask_api_default
};
//# sourceMappingURL=ids-chunk-2YEIUHFX-full.js.map
