/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  ids_data_source_default
} from "./ids-chunk-XCKXMFFA-full.js";
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-input/ids-autocomplete.ts
var IdsAutoComplete = (superclass) => class extends superclass {
  /**
   * Gets the internal IdsDataSource object
   * @returns {IdsDataSource} object
   */
  datasource = new ids_data_source_default();
  constructor(...args) {
    super(...args);
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.AUTOCOMPLETE,
      attributes.INFO_FIELD,
      attributes.SEARCH_FIELD,
      attributes.VALUE_FIELD
    ];
  }
  connectedCallback() {
    super.connectedCallback();
    if (!this.autocomplete) {
      this.destroyAutocomplete();
      return;
    }
    this.#configurePopup();
    this.#addAria();
    this.#attachKeyboardListeners();
    this.#attachEventListeners();
  }
  /**
   * Set autocomplete attribute
   * @param {string | boolean | null} value autocomplete value
   */
  set autocomplete(value) {
    const val = stringToBool(value);
    if (value === "off") {
      this.container?.setAttribute(attributes.AUTOCOMPLETE, "off");
      this.setAttribute(attributes.AUTOCOMPLETE, "off");
      this.destroyAutocomplete();
      return;
    }
    if (val) {
      this.setAttribute(attributes.AUTOCOMPLETE, "");
      this.container?.classList.add("autocomplete");
      this.#attachPopup();
      this.#addAria();
      this.#attachEventListeners();
      this.#attachKeyboardListeners();
    } else {
      this.removeAttribute(attributes.AUTOCOMPLETE);
      this.container?.classList.remove("autocomplete");
      this.destroyAutocomplete();
    }
  }
  /**
   * Get the autocomplete attribute
   * @returns {boolean} autocomplete attribute value
   */
  get autocomplete() {
    return this.hasAttribute(attributes.AUTOCOMPLETE) && this.getAttribute(attributes.AUTOCOMPLETE) !== "off";
  }
  /**
   * Set the data array of the autocomplete input
   * @param {Array<any>} value The array to use
   */
  set data(value) {
    if (this.datasource) {
      this.datasource.data = value || [];
      this.#populateListBox();
    }
  }
  /**
   * Get the data of the autocomplete
   * @returns {Array<any>} containing the dataset
   */
  get data() {
    return this?.datasource?.data || [];
  }
  /**
   * Set infoField attribute
   * Used as the field to display additional information.
   * @param {string | null} value info field value
   */
  set infoField(value) {
    if (value) {
      this.setAttribute(attributes.INFO_FIELD, value);
    } else {
      this.removeAttribute(attributes.INFO_FIELD);
    }
  }
  /**
   * Get infoField
   * @returns {string} containing the infoField
   */
  get infoField() {
    return this.getAttribute(attributes.INFO_FIELD) ?? "";
  }
  /**
   * Set searchfield attribute
   * Used as the target term to find matches in the dataset.
   * @param {string | null} value search field value
   */
  set searchField(value) {
    if (value) {
      this.setAttribute(attributes.SEARCH_FIELD, value);
    } else {
      this.removeAttribute(attributes.SEARCH_FIELD);
    }
  }
  /**
   * Get searchField
   * @returns {string} containing the searchField
   */
  get searchField() {
    const fields = this.data && Object?.keys(this.data[0] || {});
    return this.getAttribute(attributes.SEARCH_FIELD) || fields[0];
  }
  /**
   * Dataset field to use as value in selected event
   * @param {string | null} value field from the dataset
   */
  set valueField(value) {
    if (value) {
      this.setAttribute(attributes.VALUE_FIELD, value);
    } else {
      this.removeAttribute(attributes.VALUE_FIELD);
    }
  }
  /**
   * @returns {string} value field or search field as fallback
   */
  get valueField() {
    return this.getAttribute(attributes.VALUE_FIELD) || this.searchField;
  }
  /**
   * Get the internal ids-popup element
   * @returns {Element | null | any} IdsPopup Element
   * @readonly
   */
  get popup() {
    return this.shadowRoot?.querySelector("ids-popup");
  }
  /**
   * Get the internal ids-list-box element
   * @returns {Element | null | any} IdsListBox Element
   * @readonly
   */
  get listBox() {
    return this.shadowRoot?.querySelector("ids-list-box");
  }
  /**
   * Get all internal ids-list-box-option elements
   * @returns {Element | null | any} IdsListBoxOption Elements
   * @readonly
   */
  get options() {
    return this.shadowRoot?.querySelectorAll("ids-list-box-option");
  }
  /**
   * Get the selected ids-list-box-option element
   * @returns {Element | null | any} Selected IdsListBoxOption Element
   * @readonly
   */
  get isSelected() {
    return this.shadowRoot?.querySelector(`ids-list-box-option.is-selected`);
  }
  /**
   * Find matches between the input value, searchField and dataset
   * @param {string | RegExp} value value of the input field
   * @param {Array} list the dataset
   * @returns {Array<any> | null} containing matched values.
   */
  findMatches(value, list) {
    const escapedValue = value.toString().replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
    const regex = new RegExp(escapedValue, "gi");
    return list.filter((option) => option[this.searchField]?.toString()?.match(regex));
  }
  /**
   * Display matches from the dataset
   * @returns {void}
   */
  displayMatches() {
    if (this.readonly || this.disabled || this.autocomplete.toString() === "off") {
      return;
    }
    const thisAsInput = this;
    const resultsArr = this.findMatches(thisAsInput.value, this.data);
    const results = resultsArr?.map((result) => {
      const regex = new RegExp(thisAsInput.value, "gi");
      const optionText = result[this.searchField].toString()?.replace(regex, '<span class="highlight">$&</span>');
      return this.#templatelistBoxOption(
        result[this.searchField],
        optionText,
        result[this.infoField],
        result[this.valueField]
      );
    }).join("");
    if (thisAsInput.value) {
      this.openPopup();
      this.listBox.innerHTML = results || `<ids-list-box-option>${this.localeAPI.translate("NoResults")}</ids-list-box-option>`;
      this.popup.place();
    } else {
      this.clearOptions();
      this.closePopup();
    }
  }
  /**
   * Popuplate the list box with the current data
   */
  #populateListBox() {
    if (!this.listBox) return;
    if (this.value?.length) {
      this.displayMatches();
    } else {
      this.listBox.innerHTML = this.data.map((d) => {
        const value = d[this.valueField];
        const label = d[this.searchField];
        const info = d[this.infoField];
        return this.#templatelistBoxOption(label, label, info, value);
      }).join("");
    }
  }
  /**
   * Create the list box option template.
   * @param {string | null} value sets the value attr of the option
   * @param {string | null} label sets the label of the option
   * @param {string | null} info adds additional info to the option
   * @param {string | null} selectedValue sets the selected value
   * @returns {string} ids-list-box-option template.
   */
  #templatelistBoxOption(value, label, info, selectedValue) {
    info = info ? `<small slot="info">${info}</small>` : "";
    return `<ids-list-box-option data-value="${selectedValue}" value="${value}">${label}${info}</ids-list-box-option>`;
  }
  /**
   * Add internal aria attributes
   * @private
   * @returns {object} This API object for chaining
   */
  #addAria() {
    const attrs = {
      role: "combobox",
      "aria-expanded": "false",
      "aria-autocomplete": "list",
      "aria-haspopup": "listbox",
      "aria-controls": this.listBox?.getAttribute("id") || `ids-list-box-${this.id}`
    };
    if (this.listBox) {
      this.listBox.setAttribute("id", `ids-list-box-${this.id}`);
      this.listBox.setAttribute("aria-label", `Listbox`);
    }
    Object.keys(attrs).forEach((key) => this.setAttribute(key, attrs[key]));
    return this;
  }
  /**
   * Close popup
   * @returns {void}
   */
  closePopup() {
    this.popup?.hide();
  }
  /**
   * Open popup
   * @returns {void}
   */
  openPopup() {
    if (this.popup) {
      this.popup.visible = true;
      this.popup?.show();
    }
  }
  /**
   * Set the value of the input to the selected option
   * @param {Event | any} e event
   */
  selectOption(e) {
    if (e.target.nodeName === "IDS-LIST-BOX-OPTION" || e.target.parentNode?.nodeName === "IDS-LIST-BOX-OPTION") {
      this.setSelectedOption(e.target.nodeName === "IDS-LIST-BOX-OPTION" ? e.target : e.target.parentNode);
    }
    if (this.isSelected) {
      this.value = this.isSelected.getAttribute(attributes.VALUE);
      const selectedValue = this.isSelected.dataset?.value;
      this.triggerEvent("selected", this, {
        bubbles: true,
        detail: {
          elem: this,
          value: selectedValue || this.value
        }
      });
    }
    this.closePopup();
  }
  /**
   * Trigger the cleared event when input is cleared
   */
  clearOptions() {
    this.triggerEvent("cleared", this, {
      bubbles: true,
      detail: {
        elem: this,
        value: this.value
      }
    });
  }
  /**
   * Set the selected attributes on the current option
   * @param {Element | any} el element
   */
  setSelectedOption(el) {
    el.classList.add("is-selected");
    el.setAttribute("tabindex", "0");
  }
  /**
   * Remove the selected attributes on the current option
   * @param {Element | any} el element
   */
  removeSelectedOption(el) {
    el.classList.remove("is-selected");
    el.setAttribute("tabindex", "-1");
  }
  /**
   * Configure internal IdsPopup element.
   * @returns {void}
   */
  #configurePopup() {
    customElements.whenDefined("ids-popup").then(() => {
      this.popup.type = "dropdown";
      this.popup.align = "bottom, left";
      this.popup.alignTarget = this.fieldContainer;
      this.popup.y = -1;
    }).catch((err) => {
      console.info("IdsPopup component not defined", err);
    });
  }
  /**
   * Attach and configure internal IdsPopup element
   * @returns {void}
   */
  #attachPopup() {
    if (this.popup) return;
    this.container?.insertAdjacentHTML("beforeend", `
      <ids-popup part="popup">
        <ids-list-box slot="content"></ids-list-box>
      </ids-popup>
    `);
    this.#configurePopup();
  }
  /**
   * Attach internal event handlers
   * @returns {void}
   */
  #attachEventListeners() {
    this.#removeEventListeners();
    this.onEvent("keydownend.autocomplete", this, this.displayMatches);
    this.onEvent("mousedown.autocomplete", this.listBox, this.selectOption.bind(this));
    this.onEvent("blur.autocomplete", this, this.closePopup);
  }
  /**
   * Attach the keyborad listeners
   * @returns {void}
   */
  #attachKeyboardListeners() {
    this.#removeKeyboardListeners();
    this.listen(["ArrowDown"], this, (e) => {
      e.stopPropagation();
      e.stopImmediatePropagation();
      e.preventDefault();
      const selected = this.isSelected;
      const firstOption = this.options[0];
      const lastOption = this.options[this.options.length - 1];
      if (!selected) {
        this.setSelectedOption(firstOption);
      }
      if (selected?.nextElementSibling) {
        this.removeSelectedOption(selected);
        this.setSelectedOption(selected.nextElementSibling);
        selected.nextElementSibling.focus();
      }
      if (selected === lastOption) {
        this.removeSelectedOption(selected);
        this.setSelectedOption(firstOption);
      }
    });
    this.listen(["ArrowUp"], this, (e) => {
      e.stopPropagation();
      e.stopImmediatePropagation();
      e.preventDefault();
      const selected = this.isSelected;
      const firstOption = this.options[0];
      const lastOption = this.options[this.options.length - 1];
      if (e.altKey) {
        this.value = selected.getAttribute("value");
        this.closePopup();
        return;
      }
      if (selected?.previousElementSibling) {
        this.removeSelectedOption(selected);
        this.setSelectedOption(selected.previousElementSibling);
        selected.previousElementSibling.focus();
      }
      if (selected === firstOption) {
        this.removeSelectedOption(selected);
        this.setSelectedOption(lastOption);
      }
    });
    this.listen([" ", "Enter"], this.listBox, this.selectOption.bind(this));
    this.listen(["Escape"], this.listBox, this.closePopup.bind(this));
  }
  /**
   * Remove internal event handlers
   * @returns {void}
   */
  #removeKeyboardListeners() {
    this.unlisten("ArrowDown");
    this.unlisten("ArrowUp");
    this.unlisten(" ");
    this.unlisten("Enter");
    this.unlisten("Escape");
  }
  /**
   * Remove internal event handlers
   * @returns {void}
   */
  #removeEventListeners() {
    this.offEvent("keyup.autocomplete", this);
    this.offEvent("change.autocomplete", this);
    this.offEvent("blur.autocomplete", this);
  }
  /**
   * Destroy autocomplete functionality
   * @returns {void}
   */
  destroyAutocomplete() {
    this.popup?.remove();
    this.#removeEventListeners();
    this.#removeKeyboardListeners();
  }
};
var ids_autocomplete_default = IdsAutoComplete;

export {
  ids_autocomplete_default
};
//# sourceMappingURL=ids-chunk-6O62NFIL-full.js.map
