/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  deepClone
} from "./ids-chunk-G6C62L35-full.js";
import {
  sanitizeHTML
} from "./ids-chunk-5K4YUTOH-full.js";
import {
  stringToBool,
  stringToNumber
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-list-view/ids-list-view-search-mixin.ts
var IdsListViewSearchMixin = (superclass) => class extends superclass {
  /**
   * Possible Filter Modes
   */
  searchFilterModes = {
    CONTAINS: "contains",
    KEYWORD: "keyword",
    PHRASE_STARTS_WITH: "phrase-starts-with",
    WORD_STARTS_WITH: "word-starts-with"
  };
  constructor(...args) {
    super(...args);
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.SEARCH_FIELD_ID,
      attributes.SEARCH_FILTER_MODE,
      attributes.SEARCH_TERM_CASE_SENSITIVE,
      attributes.SEARCH_TERM_MIN_SIZE,
      attributes.SEARCHABLE,
      attributes.SUPPRESS_HIGHLIGHT
    ];
  }
  connectedCallback() {
    super.connectedCallback();
  }
  /**
   * Search filter callback, use for custom filter to match
   */
  searchFilterCallback = null;
  /**
   * Searchable text callback
   */
  searchableTextCallback = null;
  /**
   * Current search term
   */
  searchTerm = "";
  /**
   * Get search container element
   * @returns {HTMLDivElement|null|undefined} The search container element
   */
  get searchContainer() {
    return this.shadowRoot?.querySelector(".ids-list-view-search");
  }
  /**
   * Get search field element
   * @returns {HTMLDivElement|null|undefined} The search field element
   */
  get searchField() {
    let searchfield = this.querySelector('ids-search-field[slot="search"]');
    if (!searchfield && this.searchFieldId) {
      searchfield = this.closest("ids-container")?.querySelector(`#${this.searchFieldId}`);
    }
    return searchfield;
  }
  /**
   * Set ID of the search field element to use for the search
   * @param {string | null} value The value
   */
  set searchFieldId(value) {
    if (value) this.setAttribute(attributes.SEARCH_FIELD_ID, String(value));
    else this.removeAttribute(attributes.SEARCH_FIELD_ID);
    this.redraw?.();
  }
  get searchFieldId() {
    return this.getAttribute(attributes.SEARCH_FIELD_ID);
  }
  /**
   * Set search filter mode
   * @param {SearchFilterModes} value The value
   */
  set searchFilterMode(value) {
    if (Object.values(this.searchFilterModes).includes(value || "")) {
      this.setAttribute(attributes.SEARCH_FILTER_MODE, String(value));
    } else this.removeAttribute(attributes.SEARCH_FILTER_MODE);
  }
  get searchFilterMode() {
    const defaultVal = this.searchFilterModes.CONTAINS;
    return this.getAttribute(attributes.SEARCH_FILTER_MODE) || defaultVal;
  }
  /**
   * Set search term case sensitive
   * @param {string | boolean | null} value The value
   */
  set searchTermCaseSensitive(value) {
    if (stringToBool(value)) this.setAttribute(attributes.SEARCH_TERM_CASE_SENSITIVE, "");
    else this.removeAttribute(attributes.SEARCH_TERM_CASE_SENSITIVE);
  }
  get searchTermCaseSensitive() {
    return this.hasAttribute(attributes.SEARCH_TERM_CASE_SENSITIVE);
  }
  /**
   * Set search term min size, will trigger filtering only when its length is greater than or equals to term value.
   * @param {string | number | null} value The value
   */
  set searchTermMinSize(value) {
    const val = stringToNumber(value);
    if (!Number.isNaN(val) && val > 0) this.setAttribute(attributes.SEARCH_TERM_MIN_SIZE, val.toString());
    else this.removeAttribute(attributes.SEARCH_TERM_MIN_SIZE);
  }
  get searchTermMinSize() {
    const defaultVal = 1;
    const val = stringToNumber(this.getAttribute(attributes.SEARCH_TERM_MIN_SIZE));
    return !Number.isNaN(val) && val > 0 ? val : defaultVal;
  }
  /**
   * Set searchable which allows list view to be filtered
   * @param {string | boolean | null} value The value
   */
  set searchable(value) {
    if (stringToBool(value)) this.setAttribute(attributes.SEARCHABLE, "");
    else this.removeAttribute(attributes.SEARCHABLE);
    this.setSearchable();
  }
  get searchable() {
    return this.hasAttribute(attributes.SEARCHABLE);
  }
  /**
   * Set search term text to be suppress highlight when using searchable
   * @param {string | boolean | null} value The value
   */
  set suppressHighlight(value) {
    if (stringToBool(value)) this.setAttribute(attributes.SUPPRESS_HIGHLIGHT, "");
    else this.removeAttribute(attributes.SUPPRESS_HIGHLIGHT);
  }
  get suppressHighlight() {
    return this.hasAttribute(attributes.SUPPRESS_HIGHLIGHT);
  }
  /**
   * Get search template
   * @returns {string} The search template
   */
  searchTemplate() {
    return this.searchFieldId ? "" : `<div class="ids-list-view-search" part="search"><slot name="search"></slot></div>`;
  }
  /**
   * Get search field template
   * @returns {string} The search field template
   */
  searchFieldTemplate() {
    const cssParts = "container: searchfield-container, field-container: searchfield-field-container, input: searchfield-input, popup: searchfield-popup";
    return `<ids-search-field slot="search" label="List view search" label-state="collapsed" size="full" exportparts="${cssParts}" ids-lv-default-searchfield clearable no-margins></ids-search-field>`;
  }
  /**
   * Reset search
   * @returns {void}
   */
  resetSearch() {
    this.searchTerm = "";
    const lv = this;
    if (!lv.datasource?.filtered) return;
    lv.datasource?.filter(null);
    lv.redraw?.();
    lv.triggerEvent("filtered", lv, { bubbles: true, detail: { elem: lv, type: "clear", term: "" } });
  }
  /**
   * Set the searchable
   * @returns {void}
   */
  setSearchable() {
    const getSlotted = () => this.shadowRoot?.querySelector('slot[name="search"]')?.assignedElements()[0];
    let slotted = getSlotted();
    if (!slotted && this.searchable) {
      this.insertAdjacentHTML("afterbegin", this.searchFieldTemplate());
      slotted = getSlotted();
    } else if (!this.searchable && slotted?.hasAttribute("ids-lv-default-searchfield")) {
      slotted.remove();
    }
    const isSearchfield = !!getSlotted();
    this.container?.classList.toggle("has-searchfield", isSearchfield);
    this.searchContainer?.classList.toggle("has-searchfield", isSearchfield);
    this.#attachSearchField();
  }
  /**
   * Attaches a slotted IdsSearchField component
   * @private
   * @returns {void}
   */
  #attachSearchField() {
    const searchField = this.searchField;
    if (searchField) {
      searchField.onSearch = (term) => this.#handleSearch(term);
      this.offEvent("cleared.listviewsearch");
      this.onEvent("cleared.listviewsearch", searchField, () => this.resetSearch());
    }
  }
  /**
   * Get object props as text
   * @param {string} item The term value
   * @returns {string|HTMLElement|object} The searchable content
   */
  #objectPropsAsText(item) {
    const excludeValues = ["isFilteredOut"];
    let text = "";
    Object.keys(item).forEach((prop) => {
      if (excludeValues.indexOf(prop) > 0) return;
      const pad = text.length ? " " : "";
      text += `${pad}${item[prop]}`;
    });
    return text;
  }
  /**
   * Get searchable content
   * @private
   * @param {string} item The term value
   * @returns {string|HTMLElement|object} The searchable content
   */
  #searchableContent(item) {
    let santitize = true;
    if (typeof this.searchableTextCallback === "function") {
      return this.searchableTextCallback(item) ?? "";
    }
    let targetContent;
    if (typeof item === "string") {
      targetContent = item;
    } else if (item instanceof HTMLElement) {
      santitize = false;
      targetContent = item.innerText;
    } else {
      targetContent = this.#objectPropsAsText(item);
    }
    if (santitize) targetContent = sanitizeHTML(targetContent);
    return targetContent ?? "";
  }
  /**
   * Matches the provided term against the beginning of all words in a text string.
   * @private
   * @param {string} text searchable text.
   * @param {string} term the term for which to search in the text string.
   * @returns {boolean} true if the term is present.
   */
  #wordStartsWithFilter(text, term) {
    const parts = text.split(" ");
    for (let a = 0; a < parts.length; a++) {
      if (parts[a].indexOf(term) === 0) return true;
    }
    if (text.indexOf(term) === 0) return true;
    if (term.indexOf(" ") > 0 && text.indexOf(term) > 0) return true;
    return false;
  }
  /**
   * Handle search for given trem
   * @private
   * @param {string} term The term value
   * @returns {void}
   */
  #handleSearch(term) {
    const lv = this;
    const isTermString = typeof term === "string";
    if (!isTermString || isTermString && term === "") return this.resetSearch();
    if (term.length < this.searchTermMinSize) {
      this.resetSearch();
      return;
    }
    if (this.searchTerm === term) return;
    this.searchTerm = term;
    if (!this.searchTermCaseSensitive) {
      term = term.toLowerCase();
    }
    const searchItemIterator = (item) => {
      let text = this.#searchableContent(item);
      if (!this.searchTermCaseSensitive) {
        text = text.toLowerCase().trim();
      }
      const modes = this.searchFilterModes;
      let match = false;
      if (this.searchFilterMode === modes.WORD_STARTS_WITH) {
        match = this.#wordStartsWithFilter(text, term);
      }
      if (this.searchFilterMode === modes.PHRASE_STARTS_WITH && text.indexOf(term) === 0) {
        match = true;
      }
      if (this.searchFilterMode === modes.CONTAINS && text.indexOf(term) >= 0) {
        match = true;
      }
      if (this.searchFilterMode === modes.KEYWORD) {
        const keywords = term.split(" ");
        for (let i = 0; i < keywords.length; i++) {
          if (text.indexOf(keywords[i]) >= 0) {
            match = true;
            break;
          }
        }
      }
      return !match;
    };
    let itemIterator = searchItemIterator;
    if (typeof this.searchFilterCallback === "function") {
      itemIterator = this.searchFilterCallback(term);
    }
    lv.datasource.filter(itemIterator);
    lv.redraw?.();
    lv.triggerEvent("filtered", lv, { bubbles: true, detail: { elem: lv, type: "apply", term } });
  }
  /**
   * Set search term highlight
   * @param {string | HTMLElement | object} item The from data item
   * @param {string | null} fulltext the item's fulltext that needs to be searched
   * @returns {string} search term highlight
   */
  searchHighlight(item, fulltext = null) {
    if (this.suppressHighlight || !item || !this.searchTerm || this.searchTerm === "") return item;
    let regex = null;
    const modes = this.searchFilterModes;
    const flag = this.searchTermCaseSensitive ? "g" : "gi";
    const replaceTmpl = (matched) => `<strong class="highlight">${matched}</strong>`;
    let replaceMatch = (s) => s.replace(regex, replaceTmpl);
    if (this.searchFilterMode === modes.WORD_STARTS_WITH) {
      regex = new RegExp(`(^|\\s)(${this.searchTerm})`, flag);
      replaceMatch = (s) => s.replace(regex, (m) => m.replace(new RegExp(`(${this.searchTerm})`, flag), replaceTmpl));
    } else if (this.searchFilterMode === modes.PHRASE_STARTS_WITH) {
      regex = new RegExp(`^(${this.searchTerm})`, flag);
    } else if (this.searchFilterMode === modes.CONTAINS || this.searchFilterMode === modes.KEYWORD) {
      regex = new RegExp(`(${this.searchTerm})`, flag);
    }
    if (!regex) return item;
    let term = this.searchTerm;
    let text = fulltext || this.#searchableContent(item);
    let cloneItem = deepClone(item);
    if (!this.searchTermCaseSensitive) {
      term = term.toLowerCase();
      text = text.toLowerCase();
    }
    if (text.indexOf(term) >= 0) {
      if (typeof cloneItem === "string" && text === cloneItem) {
        cloneItem = replaceMatch(cloneItem);
      } else if (cloneItem instanceof HTMLElement) {
        const itmText = cloneItem.innerText;
        const sHtml = sanitizeHTML(cloneItem.innerText);
        if (text === sHtml) cloneItem.innerText = replaceMatch(itmText);
      } else {
        for (const [key, value] of Object.entries(cloneItem)) {
          const typedVal = value;
          const val = this.searchTermCaseSensitive ? typedVal : typedVal?.toString().toLowerCase();
          if (text === val) cloneItem[key] = replaceMatch(typedVal);
        }
      }
    }
    return cloneItem;
  }
};
var ids_list_view_search_mixin_default = IdsListViewSearchMixin;

export {
  ids_list_view_search_mixin_default
};
//# sourceMappingURL=ids-chunk-EAGXDJTZ-full.js.map
