/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  stringToBool,
  stringToNumber
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-data-grid/ids-data-grid-search-mixin.ts
var IdsDataGridSearchMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  /**
   * Current search term
   */
  #searchTerm = "";
  /**
   * Reference to the search field element
   */
  #searchField = null;
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.SEARCHABLE,
      attributes.SEARCH_TERM_MIN_SIZE,
      attributes.SEARCH_FIELD,
      attributes.SEARCH_FIELD_ID
    ];
  }
  attributeChangedCallback(name, oldValue, newValue) {
    super.attributeChangedCallback(name, oldValue, newValue);
    if (oldValue === newValue) return;
    if (name === attributes.SEARCHABLE) this.#searchable();
  }
  #searchable() {
    if (!this.searchField && this.searchable) {
      this.toolbar?.insertAdjacentHTML("afterbegin", this.searchFieldTemplate());
      this.searchField = this.toolbar?.querySelector("ids-search-field") || null;
    }
    this.dataGrid.wrapper?.classList.toggle("has-searchfield", !!this.searchField);
    this.#attachEventListeners();
  }
  connectedCallback() {
    super.connectedCallback?.();
    this.dataGrid.pager?.onEvent("pagenumberchange", this, () => {
      this.highlightSearchRows();
    });
    this.dataGrid.pager?.onEvent("pagesizechange", this, () => {
      this.highlightSearchRows();
    });
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
    this.dataGrid?.pager?.offEvent("pagenumberchange", this);
    this.dataGrid?.pager?.offEvent("pagesizechange", this);
    this.#searchField = null;
  }
  /**
   * Reference to the data grid parent
   * @returns {IdsDataGrid} the data grid parent
   */
  get dataGrid() {
    return this;
  }
  /**
   * Reference to the data grid toolbar
   * @returns {HTMLElement} the toolbar
   */
  get toolbar() {
    const toolbar = this.dataGrid.shadowRoot?.querySelector(".ids-data-grid-toolbar");
    if (!toolbar) {
      this.dataGrid?.wrapper?.insertAdjacentHTML("afterbegin", '<div class="ids-data-grid-toolbar"></div>');
      return this.dataGrid.shadowRoot?.querySelector(".ids-data-grid-toolbar");
    }
    return toolbar;
  }
  /**
   * Attach event listeners for search field
   */
  #attachEventListeners() {
    if (!this.searchField) return;
    const input = this.searchField?.input ?? this.searchField;
    const onInput = (e) => this.#onSearch(e.target?.value || "");
    input?.removeEventListener("input", onInput);
    input?.addEventListener("input", onInput);
    const onCleared = () => this.#onSearch("");
    this.searchField?.removeEventListener("cleared", onCleared);
    this.searchField?.addEventListener("cleared", onCleared);
  }
  /**
   * Handles the search event
   * @param {string} value The search value
   * @returns {void}
   */
  #onSearch(value) {
    if (value !== "" && value.length > this.searchTermMinSize) {
      this.#searchTerm = value.toLowerCase();
      return this.#handleSearchKeyword();
    }
    this.dataGrid.filters.applyFilter();
    this.resetHighlightSearchRows();
  }
  /**
   * Get search field template
   * @returns {string} The search field template
   */
  searchFieldTemplate() {
    const cssParts = "container: searchfield-container, field-container: searchfield-field-container, input: searchfield-input, popup: searchfield-popup";
    return `<ids-search-field id="data-grid-search-field" label="Search" label-state="collapsed" size="" exportparts="${cssParts}" clearable no-margins></ids-search-field>`;
  }
  /**
   * Set searchable which allows list view to be filtered
   * @param {string | boolean | null} value The value
   */
  set searchable(value) {
    this.toggleAttribute(attributes.SEARCHABLE, stringToBool(value));
  }
  get searchable() {
    return this.hasAttribute(attributes.SEARCHABLE);
  }
  /**
   * Set search term min size, will trigger filtering only when its length is greater than or equals to term value.
   * @param {string | number | null} value The value
   */
  set searchTermMinSize(value) {
    const val = stringToNumber(value);
    if (!Number.isNaN(val) && val > 0) this.setAttribute(attributes.SEARCH_TERM_MIN_SIZE, val.toString());
    else this.removeAttribute(attributes.SEARCH_TERM_MIN_SIZE);
  }
  get searchTermMinSize() {
    const val = stringToNumber(this.getAttribute(attributes.SEARCH_TERM_MIN_SIZE));
    return !Number.isNaN(val) && val > 0 ? val : 1;
  }
  /**
   * Set search field
   * @param {string} value The value
   */
  set searchFieldId(value) {
    if (value) {
      this.setAttribute(attributes.SEARCH_FIELD_ID, value);
      this.searchField = document.querySelector(`#${value}`);
    } else {
      this.removeAttribute(attributes.SEARCH_FIELD_ID);
    }
  }
  get searchFieldId() {
    return this.getAttribute(attributes.SEARCH_FIELD_ID) || "";
  }
  /**
   * Set search field
   * @param {HTMLElement | IdsSearchField | null} value - A custom search element
   */
  set searchField(value) {
    this.#searchField = value;
    this.#searchable();
  }
  /**
   * Get search field
   * @returns {HTMLElement | IdsSearchField | null} value - The custom search element
   */
  get searchField() {
    return this.#searchField;
  }
  /**
   * Handles the search keyword
   */
  #handleSearchKeyword() {
    const filterExpr = [];
    const term = (this.#searchTerm || "").toLowerCase();
    filterExpr.push({
      column: "all",
      operator: "contains",
      value: term,
      keywordSearch: true
    });
    this.dataGrid.filters?.applyFilter(filterExpr);
    this.highlightSearchRows();
    this.triggerEvent("searched.datagrid", this, {
      detail: {
        value: this.#searchTerm,
        result: this.dataGrid.datasource.data
      }
    });
  }
  resetHighlightSearchRows() {
    this.container?.querySelectorAll("ids-data-grid-cell").forEach((cell) => {
      cell.innerHTML = cell.innerHTML.replace(/<strong class="highlight">/g, "").replace(/<\/strong>/g, "");
    });
  }
  highlightSearchRows() {
    if (!this.#searchTerm || this.#searchTerm === "") return;
    this.container?.querySelectorAll("ids-data-grid-cell").forEach((cell) => {
      const text = cell.textContent || "";
      if (!text.toLowerCase().includes(this.#searchTerm)) return;
      const regex = new RegExp(`(${this.#searchTerm})`, "gi");
      const replaceTmpl = (matched) => `<strong class="highlight">${matched}</strong>`;
      const replaceMatch = (s) => s.replace(regex, replaceTmpl);
      const cellHtml = cell.innerHTML;
      cell.innerHTML = cellHtml.replace(text, replaceMatch(text));
    });
  }
};
var ids_data_grid_search_mixin_default = IdsDataGridSearchMixin;

export {
  ids_data_grid_search_mixin_default
};
//# sourceMappingURL=ids-chunk-EO4KAPVD-full.js.map
