/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  WORKSHEET_TEMPLATE
} from "./ids-chunk-6SVBJPMV-full.js";

// src/utils/ids-excel-exporter/ids-excel-formatter.ts
var VALID_TYPES = ["string", "number", "date", "time"];
var CELL_PADDING = 2;
var XLSXFormatter = class {
  columns = [];
  /**
   * Generate worksheet xml string from data
   * @param {Record<string, any>} data user data
   * @param {Array<ExcelColumn>} columnConfig column configuration
   * @returns {string} xlsx formatted worksheet string
   */
  generateWorksheet(data, columnConfig) {
    this.prepareColumnConfig(columnConfig);
    const dataHeader = this.generateHeaderRow(this.columns);
    const dataBody = this.generateRows(data);
    const sheetData = `${dataHeader}${dataBody}`;
    const colStyles = this.generateColWidths(this.columns);
    let worksheet = WORKSHEET_TEMPLATE.replace("{sheetDataPlaceholder}", sheetData);
    worksheet = worksheet.replace("{colPlaceholder}", colStyles);
    return worksheet;
  }
  /**
   * Prepares column configuration referenced in worksheet creation
   * @param {Array<ExcelColumn>} columnConfig column configuration
   */
  prepareColumnConfig(columnConfig) {
    if (!columnConfig) return;
    this.columns = columnConfig.map((config, idx) => {
      const xlsxCol = {
        ...config,
        refLetter: this.generateColumnLetter(idx),
        width: config.name.length + CELL_PADDING
      };
      return xlsxCol;
    });
  }
  /**
   * Generates <cols> section of worksheet
   * Width is determined by max char length of data column
   * @param {Array<XLSXColumn>} columns column config
   * @returns {string} <cols> worksheet string
   */
  generateColWidths(columns) {
    return columns.reduce((cols, col, idx) => {
      const colIndex = idx + 1;
      const colWidth = col.width;
      const colStr = `<col min="${colIndex}" max="${colIndex}" width="${colWidth}" bestFit="1" customWidth="1" />`;
      return `${cols}${colStr}`;
    }, "");
  }
  /**
   * Recursively creates Excel column letter by column index
   * @param {number} colIndex zero-based column index
   * @returns {string} Excel Column letter
   */
  generateColumnLetter(colIndex) {
    if (typeof colIndex !== "number") {
      return "";
    }
    const prefix = Math.floor(colIndex / 26);
    const letter = String.fromCharCode(97 + colIndex % 26).toUpperCase();
    if (prefix === 0) {
      return letter;
    }
    return this.generateColumnLetter(prefix - 1) + letter;
  }
  /**
   * Escapes special characters for excel string cells
   * @param {string} str cell string
   * @returns {string} escaped, trimmed cell string
   */
  escapeExcelString(str) {
    const map = {
      "&": "&amp;",
      "<": "&lt;",
      ">": "&gt;",
      '"': "&quot;",
      "'": "&#39;"
    };
    return str.replace(/[&<>"']/g, (m) => map[m]);
  }
  /**
   * Create formatted string cell
   * @param {string} value string value
   * @param {string} cellRef cell ref location
   * @returns {string} xlsx xml string cell
   */
  formatStringCell(value, cellRef) {
    let cleanValue = value ?? "";
    cleanValue = this.escapeExcelString(String(cleanValue).trim());
    return `<c r="${cellRef}" t="inlineStr"><is><t>${cleanValue}</t></is></c>`;
  }
  /**
   * Create a cell with a certain type
   * @param {any} value cell value
   * @param {string} cellRef cell ref location
   * @param {string} type cell type
   * @returns {string} xlsx xml number cell
   */
  formatTypedCell(value, cellRef, type) {
    if (type === "date") {
      return this.formatDateCell(value, cellRef);
    }
    if (type === "time") {
      return this.formatTimeCell(value, cellRef);
    }
    value = Number.isNaN(value) ? "" : value;
    value ??= "";
    return `<c r="${cellRef}"><v>${value}</v></c>`;
  }
  /**
   * Convert JS Date object to excel date value
   * Excel date is number of days since Jan 1 1900
   * @see {@link https://support.microsoft.com/en-us/office/datetime-function-812ad674-f7dd-4f31-9245-e79cfa358a4e}
   * @see {@link https://www.flyaga.info/converting-a-javascript-date-object-to-an-excel-date-time-serial-value/}
   * @param {Date} date JS Date Object
   * @returns {number} excel date value
   */
  createExcelDate(date) {
    const epochDiff = 25569;
    const dayInMs = 1e3 * 60 * 60 * 24;
    return epochDiff + (date.getTime() - date.getTimezoneOffset() * 60 * 1e3) / dayInMs;
  }
  /**
   * Creates time cell string
   * Defaults to en_US formatting of time
   * @param {string} dateStr parseable Date string
   * @param {string} cellRef cell reference string
   * @returns {string} cell time string
   */
  formatTimeCell(dateStr, cellRef) {
    const d = new Date(dateStr);
    if (!Number.isNaN(d.getTime())) {
      const excelDate = this.createExcelDate(d);
      return `<c r="${cellRef}" s="3"><v>${excelDate}</v></c>`;
    }
    return this.formatStringCell("", cellRef);
  }
  /**
   * Creates date cell string
   * Defaults to en_US formatting of dates
   * @param {string} dateStr parseable Date string
   * @param {string} cellRef cell reference string
   * @returns {string} cell date string
   */
  formatDateCell(dateStr, cellRef) {
    const d = new Date(dateStr);
    if (!Number.isNaN(d.getTime())) {
      const excelDate = this.createExcelDate(d);
      return `<c r="${cellRef}" s="2"><v>${excelDate}</v></c>`;
    }
    return this.formatStringCell("", cellRef);
  }
  /**
   * Factory function to format cells of different types
   * @param {XLSXColumn} col column
   * @param {any} value field value
   * @param {number} cellIndex column number
   * @param {number} rowIndex row number
   * @returns {string} xlsx xml formatted cell
   */
  formatCell(col, value, cellIndex, rowIndex) {
    const cellConfig = col;
    let cellType = VALID_TYPES.includes(cellConfig?.type) ? cellConfig.type : "string";
    const cellRefLetter = cellConfig.refLetter || this.generateColumnLetter(cellIndex);
    const cellRef = `${cellRefLetter}${rowIndex}`;
    const valueWidth = String(value).length + CELL_PADDING;
    cellConfig.width = Math.max(valueWidth, cellConfig.width);
    if (cellType === "string" && this.canCastAsNumber(value)) {
      cellType = "number";
    }
    return cellType === "string" ? this.formatStringCell(value, cellRef) : this.formatTypedCell(value, cellRef, cellType);
  }
  canCastAsNumber(value) {
    if (typeof value === "number" && !Number.isNaN(Number(value))) {
      return true;
    }
    if (value?.length && !Number.isNaN(Number(value))) {
      return true;
    }
    return false;
  }
  /**
   * Create xlsx xml formatted row
   * @param {Record<string, any>} row row data
   * @param {number} rowIndex row index
   * @returns {string} xlsx xml formatted row
   */
  formatRow(row, rowIndex) {
    const rowCells = this.columns.reduce((rowString, col, idx) => {
      const value = row[col.id] || row[col.field];
      const cell = this.formatCell(col, value, idx, rowIndex);
      return `${rowString}${cell}`;
    }, "");
    return `<row r="${rowIndex}">${rowCells}</row>`;
  }
  /**
   * Create header row for excel sheet
   * @param {Array<XLSXColumn>} columns columns config
   * @returns {string} header excel string
   */
  generateHeaderRow(columns) {
    const headerCells = columns.reduce((headerStr, col) => {
      const cellR = col.refLetter;
      const name = col.name;
      const cell = `<c r="${cellR}1" t="inlineStr" s="1"><is><t>${name}</t></is></c>`;
      return `${headerStr}${cell}`;
    }, "");
    return `<row r="1">${headerCells}</row>`;
  }
  /**
   * Creates xlsx formatted rows
   * @param {Array<Record<string, any>>} rows array of row data
   * @returns {string} xml formatted rows
   */
  generateRows(rows) {
    return rows.reduce((prevRow, row, idx) => {
      const rowIndex = idx + 2;
      return prevRow + this.formatRow(row, rowIndex);
    }, "");
  }
  /**
   * Clean up any references
   */
  destroy() {
    this.columns = [];
  }
};

export {
  XLSXFormatter
};
//# sourceMappingURL=ids-chunk-KH4KMDY6-full.js.map
