/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */

// src/utils/ids-dom-utils/ids-dom-utils.ts
function getClosestShadow(node) {
  let parent = node && node.parentNode;
  while (parent) {
    if (parent.toString() === "[object ShadowRoot]") {
      return parent;
    }
    parent = parent.parentNode;
  }
  return void 0;
}
function getClosestContainerNode(node) {
  return getClosestShadow(node) || document;
}
function getClosestRootNode(node) {
  return getClosestShadow(node)?.host?.parentNode || document;
}
function getClosest(node, selector) {
  let parent = node && node.parentNode;
  while (parent) {
    if (parent.toString() === "[object ShadowRoot]") {
      parent = parent.host;
    }
    if (parent.toString() === "[object HTMLDocument]") {
      return void 0;
    }
    if (typeof parent.matches === "function" && parent.matches(selector)) {
      return parent;
    }
    parent = parent.parentNode;
  }
  return void 0;
}
function parents(node, selector = "body") {
  const parentsList = [];
  for (let parent = node?.parentNode; parent; parent = parent.toString() === "[object ShadowRoot]" ? parent.host : parent?.parentNode) {
    parentsList.push(parent);
    if (parent.matches?.(selector)) break;
  }
  return parentsList;
}
function nextUntil(node, selector) {
  const siblings = [];
  node = node.nextElementSibling;
  while (node) {
    if (node.matches(selector)) break;
    siblings.push(node);
    node = node.nextElementSibling;
  }
  return siblings;
}
function next(node, selector) {
  node = node.nextElementSibling;
  while (node) {
    if (node.matches(selector)) return node;
    node = node.nextElementSibling;
  }
  return node;
}
function previous(node, selector) {
  node = node.previousElementSibling;
  while (node) {
    if (node.matches(selector)) return node;
    node = node.previousElementSibling;
  }
  return node;
}
function transitionToPromise(el, property, value) {
  if (!el) return Promise.resolve();
  return new Promise((resolve) => {
    el.style[property] = value;
    const transitionEnded = (e) => {
      if (e.propertyName !== property) resolve(true);
      el.removeEventListener("transitionend", transitionEnded);
      resolve(true);
    };
    el.addEventListener("transitionend", transitionEnded);
  });
}
function waitForTransitionEnd(el, property) {
  return new Promise((resolve) => {
    const transitionEnded = (e) => {
      if (e.propertyName !== property) resolve(true);
      el.removeEventListener("transitionend", transitionEnded);
      resolve(true);
    };
    el.addEventListener("transitionend", transitionEnded);
  });
}
function waitForAnimationEnd(el, animationName) {
  return new Promise((resolve) => {
    if (typeof AnimationEvent !== "function") resolve(true);
    const animationEnded = (e) => {
      if (e.animationName !== animationName) return;
      el.removeEventListener("animationend", animationEnded);
      resolve(true);
    };
    el.addEventListener("animationend", animationEnded);
  });
}
function getEditableRect(rect) {
  const {
    bottom,
    left,
    right,
    top,
    height,
    width,
    x,
    y
  } = rect;
  return {
    bottom,
    left,
    right,
    top,
    height,
    width,
    x,
    y
  };
}
function checkOverflow(el, checkHeight) {
  if (!el) return false;
  if (checkHeight === void 0) checkHeight = true;
  const curOverflow = el.style.overflow;
  let changedOverflow = false;
  if (!curOverflow || curOverflow === "visible") {
    el.style.overflow = "hidden";
    changedOverflow = true;
  }
  const isOverflowing = checkHeight ? el.clientWidth < el.scrollWidth || el.clientHeight < el.scrollHeight : el.clientWidth < el.scrollWidth;
  if (changedOverflow) {
    el.style.overflow = curOverflow;
  }
  return isOverflowing;
}
var toggleScrollbar = (el, classEl, doToggle) => {
  let didToggle = false;
  const classTargetEl = classEl || el;
  if (el instanceof HTMLElement) {
    if (doToggle === void 0 && el.scrollHeight > el.clientHeight || doToggle === true) {
      classTargetEl.classList.add("has-scrollbar");
      didToggle = true;
    } else {
      classTargetEl.classList.remove("has-scrollbar");
    }
  }
  return didToggle;
};
function hasClass(el, className) {
  return el?.classList.contains(className);
}
function getElementAtMouseLocation() {
  let mousePos = [0, 0];
  const getCurrentCoords = (e) => {
    mousePos = [e.clientX, e.clientY];
    document.removeEventListener("mousemove", getCurrentCoords);
  };
  document.addEventListener("mousemove", getCurrentCoords);
  return document.elementFromPoint(...mousePos);
}
function querySelectorAllShadowRoot(selector, rootNode = document.body) {
  const arr = [];
  const traverser = (node) => {
    if (node.nodeType !== Node.ELEMENT_NODE) {
      return;
    }
    if (node.matches(selector)) {
      arr.push(node);
    }
    const children = node.children;
    if (children.length) {
      for (const child of children) {
        traverser(child);
      }
    }
    const shadowRoot = node.shadowRoot;
    if (shadowRoot) {
      const shadowChildren = shadowRoot.children;
      for (const shadowChild of shadowChildren) {
        traverser(shadowChild);
      }
    }
  };
  traverser(rootNode);
  return arr;
}
function validMaxHeight(value) {
  let val = parseInt(value, 10);
  val = !Number.isNaN(val) && val > -1 ? `${val}px` : null;
  return val;
}
function parseNumberWithUnits(value) {
  let val = "";
  if (typeof value === "number" && !Number.isNaN(value)) {
    val = `${value}px`;
  } else if (typeof value === "string") {
    const last = parseInt(value.slice(-1), 10);
    if (typeof last === "number" && !Number.isNaN(last)) {
      val = `${value}px`;
    } else if (/(px|em|vw|vh|ch|%)$/g.test(value) && !Number.isNaN(parseInt(value, 10))) {
      val = value;
    }
  }
  return val;
}
function isScrolled(element) {
  const isScrolledLeft = Math.abs(element.scrollLeft) > 0;
  const isScrolledRight = Math.abs(element.scrollLeft) + element.clientWidth < element.scrollWidth;
  return {
    isScrolledLeft,
    isScrolledRight
  };
}

export {
  getClosestShadow,
  getClosestContainerNode,
  getClosestRootNode,
  getClosest,
  parents,
  nextUntil,
  next,
  previous,
  transitionToPromise,
  waitForTransitionEnd,
  waitForAnimationEnd,
  getEditableRect,
  checkOverflow,
  toggleScrollbar,
  hasClass,
  getElementAtMouseLocation,
  querySelectorAllShadowRoot,
  validMaxHeight,
  parseNumberWithUnits,
  isScrolled
};
//# sourceMappingURL=ids-chunk-LQYSVESW-full.js.map
