/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  ids_mask_global_default
} from "./ids-chunk-HPO4ADMP-full.js";
import {
  dateMask,
  numberMask,
  rangeDateMask
} from "./ids-chunk-L5LKJLMG-full.js";
import {
  PLACEHOLDER_CHAR,
  convertPatternFromString
} from "./ids-chunk-2GKEPJIA-full.js";
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-mask-mixin/ids-mask-mixin.ts
var MASK_ATTRIBUTES = [
  attributes.MASK,
  attributes.MASK_GUIDE,
  attributes.MASK_RETAIN_POSITIONS,
  attributes.MASK_OPTIONS
];
var IdsMaskMixin = (superclass) => class extends superclass {
  maskState = {
    guide: false,
    keepCharacterPositions: false,
    options: {},
    previousMaskResult: "",
    previousPlaceholder: ""
  };
  constructor(...args) {
    super(...args);
  }
  /**
   * @returns {Array<string>} IdsInput component observable attributes
   */
  static get attributes() {
    return [
      ...superclass.attributes,
      ...MASK_ATTRIBUTES
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
    this.handleMaskEvents();
    this.processMaskWithCurrentValue();
  }
  /**
   * @readonly
   * @returns {maskAPI} reference to a global IDS Mask instance
   */
  get maskAPI() {
    return ids_mask_global_default;
  }
  set maskGuide(val) {
    const trueVal = stringToBool(val);
    this.maskState.guide = trueVal;
    this.processMaskWithCurrentValue();
  }
  get maskGuide() {
    return this.maskState.guide;
  }
  /**
   * @returns {object} defined Mask options
   */
  get maskOptions() {
    return this.maskState.options;
  }
  /**
   * @param {object} val incoming Mask options
   */
  set maskOptions(val) {
    if (typeof val === "object") {
      this.maskState.options = val;
    }
  }
  /**
   * @returns {Function} a Pipe Function for modifying Mask output
   */
  get maskPipe() {
    return this.maskState.pipe;
  }
  /**
   * @param {Function} val a Pipe Function for modifying Mask output
   */
  set maskPipe(val) {
    if (typeof val === "function") {
      this.maskState.pipe = val;
    }
  }
  set maskRetainPositions(val) {
    const trueVal = stringToBool(val);
    this.maskState.keepCharacterPositions = trueVal;
  }
  get maskRetainPositions() {
    return this.maskState.keepCharacterPositions;
  }
  /**
   * Retrieves the currently-stored mask pattern.
   * @returns {string|Function|Array<string|RegExp>} representing the stored mask pattern
   */
  get mask() {
    return this.maskState.pattern;
  }
  /**
   * Sets the Mask pattern to be used.
   * @param {string|Function|Array<string|RegExp>} val the mask pattern on which to conform input
   */
  set mask(val) {
    let trueVal;
    if (Array.isArray(val) || typeof val === "function") {
      trueVal = val;
    } else {
      switch (val) {
        // Using 'date' as a string automatically connects the standard date mask function
        case "date":
        case "time":
          trueVal = dateMask;
          this.onLocaleChange = (locale) => {
            if (!this.maskOptions.format) {
              this.maskOptions.format = locale.calendar().dateFormat.short;
            }
          };
          break;
        case "rangeDate":
          trueVal = rangeDateMask;
          this.onLocaleChange = (locale) => {
            if (!this.maskOptions.format) {
              this.maskOptions.format = locale.calendar().dateFormat.short;
            }
          };
          break;
        // Using 'number' as a string automatically connects the standard number mask function
        case "number":
          trueVal = numberMask;
          this.onLocaleChange = (locale) => {
            const newLocale = locale.locale;
            this.maskOptions.symbols = {
              currency: newLocale.options.currencySign,
              decimal: newLocale.options.numbers.decimal,
              negative: newLocale.options.numbers.minusSign,
              thousands: newLocale.options.numbers.group
            };
          };
          break;
        default:
          trueVal = convertPatternFromString(val);
          this.onLocaleChange = void 0;
          break;
      }
    }
    this.maskState.pattern = trueVal;
    if (typeof this.onLocaleChange === "function" && this.localeAPI) {
      this.onLocaleChange(this.localeAPI);
    }
  }
  handleMaskEvents() {
    this.onEvent("input", this, () => this.processMaskWithCurrentValue());
  }
  /**
   * Uses an input value and pattern options to process a masked string.
   * @param {string} rawValue the value to be checked for masking.
   * @param {IdsMaskOptions} opts various options that can be passed to the masking process.
   * @param {boolean} [doSetValue] if true, attempts to set input state when masking completes
   * @returns {string|boolean} the result of the mask.  If no masking was performed, return `false`
   */
  processMask = (rawValue, opts = {}, doSetValue = false) => {
    if (!this.mask) {
      return false;
    }
    const previousValue = this.maskState.previousMaskResult;
    if (rawValue === previousValue) {
      return false;
    }
    const posBegin = this.input.selectionStart || 0;
    const posEnd = this.input.selectionEnd || 0;
    rawValue = ids_mask_global_default.getSafeRawValue(rawValue);
    const processOptions = {
      caretTrapIndexes: [],
      guide: this.maskState.guide,
      locale: this.localeAPI,
      keepCharacterPositions: this.maskState.keepCharacterPositions,
      pattern: this.mask,
      patternOptions: opts,
      placeholderChar: PLACEHOLDER_CHAR,
      previousMaskResult: previousValue,
      selection: {
        start: posBegin,
        end: posEnd,
        contents: ""
      }
    };
    if (posBegin !== posEnd) {
      processOptions.selection.contents = rawValue.substring(posBegin, posEnd);
    }
    if (typeof this.maskPipe === "function") {
      processOptions.pipe = this.maskPipe;
    }
    const processed = ids_mask_global_default.process(rawValue, processOptions);
    if (!processed.maskResult) {
      return false;
    }
    let finalValue = processed.conformedValue;
    if (processed.pipedValue) {
      finalValue = processed.pipedValue;
    }
    if (finalValue !== "" && opts.suffix && !finalValue.includes(opts.suffix)) {
      finalValue += `${opts.suffix}`;
    }
    const adjustCaretOpts = {
      conformedValue: finalValue,
      rawValue,
      caretPos: processed.caretPos,
      placeholder: processed.placeholder,
      placeholderChar: processOptions.placeholderChar,
      previousMaskResult: previousValue,
      previousPlaceholder: this.maskState.previousPlaceholder
    };
    if (processed.pipedCharacterIndexes) {
      adjustCaretOpts.indexesOfPipedChars = processed.pipedCharIndexes;
    }
    if (processed.caretTrapIndexes) {
      adjustCaretOpts.caretTrapIndexes = processed.caretTrapIndexes;
    }
    processed.caretPos = ids_mask_global_default.adjustCaretPosition(adjustCaretOpts);
    this.maskState.previousMaskResult = finalValue;
    this.maskState.previousPlaceholder = processed.placeholder;
    if (doSetValue) {
      this.value = finalValue;
      this.safelySetSelection(this.shadowRoot, processed.caretPos, processed.caretPos);
    }
    return finalValue;
  };
  /**
   * Uses this current input value and pattern options defined to process a
   * masked string, also setting input state.
   * @returns {object} the result of the mask
   */
  processMaskWithCurrentValue() {
    return this.processMask(this.value, this.maskOptions, true);
  }
  /**
   * Uses a provided value with stored mask options to process a masked string,
   * without setting input state.
   * @param {string} rawValue a text value to process against the mask
   * @returns {object} the result of the mask
   */
  processMaskFromProperty(rawValue = "") {
    return this.processMask(rawValue, this.maskOptions, false);
  }
  /**
   * @private
   * @param {ShadowRoot|Document} host either the Document, or a relevant Shadow Root
   * @param {number} startPos starting position
   * @param {number} endPos end position
   * @returns {void}
   */
  safelySetSelection(host = document, startPos = 0, endPos = 0) {
    if (host?.activeElement === this.input) {
      this.input.setSelectionRange(startPos, endPos, "none");
    }
  }
};
var ids_mask_mixin_default = IdsMaskMixin;

export {
  ids_mask_mixin_default
};
//# sourceMappingURL=ids-chunk-MXUEIZUE-full.js.map
