/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */

// src/mixins/ids-keyboard-mixin/ids-keyboard-mixin.ts
var IdsKeyboardMixin = (superclass) => class extends superclass {
  hotkeys = null;
  pressedKeys = null;
  keyDownHandler;
  keyUpHandler;
  constructor(...args) {
    super(...args);
    this.initKeyboardHandlers();
  }
  static get attributes() {
    return [
      ...superclass.attributes
    ];
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
    this.detachAllListeners();
    this.hotkeys = null;
    this.pressedKeys = null;
  }
  /**
   * Initializes the keyboard management system with the current object
   * @private
   */
  initKeyboardHandlers() {
    this.hotkeys = /* @__PURE__ */ new Map();
    this.pressedKeys = /* @__PURE__ */ new Map();
    this.keyDownHandler = (e) => {
      this.press(e.key);
      this.dispatchHotkeys(e);
    };
    this.offEvent("keydown.keyboard", this);
    this.onEvent("keydown.keyboard", this, this.keyDownHandler);
    this.keyUpHandler = (e) => {
      this.unpress(e.key);
    };
    this.offEvent("keyup.keyboard", this);
    this.onEvent("keyup.keyboard", this, this.keyUpHandler);
  }
  /**
   * Add a key to the pressedKeys Map.
   * @private
   * @param {string} key a string representing a KeyboardEvent.key that was pressed
   * @returns {Map} the current set of pressed keys
   */
  press(key) {
    return this.pressedKeys?.set(`${key}`, true);
  }
  /**
   * Add a listener for a key or set of keys
   * @param {Array|string} keycode An array of all matchinng keycodes
   * @param {HTMLElement} elem The object with the listener attached
   * @param {Function} callback The call back when this combination is met
   */
  listen(keycode, elem, callback) {
    const keycodes = Array.isArray(keycode) ? keycode : [keycode];
    for (const c of keycodes) {
      this.hotkeys?.set(`${c}`, callback);
    }
  }
  /**
   * Removes a single applied listener for a hotkey combination
   * @param {string} key An array of all matching keycodes
   * @returns {Map} the current set of hotkeys
   */
  unlisten(key) {
    return this.hotkeys?.delete(`${key}`);
  }
  /**
   * Remove a key from the pressedKeys map.
   * @private
   * @param {string} key a string representing a KeyboardEvent.key that is no longer active
   * @returns {boolean} whether or not the key had been previously logged as "pressed"
   */
  unpress(key) {
    return this.pressedKeys?.delete(`${key}`);
  }
  /**
   * Dispatch an event on any active listeners
   * @private
   * @param {object} e a string representing a KeyboardEvent.key that is no longer active
   * @returns {void}
   */
  dispatchHotkeys(e) {
    this.hotkeys?.forEach((value, key) => {
      if (key.split(",").indexOf(e.key) > -1) {
        value(e);
      }
    });
  }
  /**
   * Remove all handlers and clear memory
   */
  detachAllListeners() {
    if (this.keyDownHandler && this.offEvent) {
      this.offEvent("keydown.keyboard", this, this.keyDownHandler);
      delete this.keyDownHandler;
    }
    if (this.keyUpHandler && this.offEvent) {
      this.offEvent("keyup.keyboard", this, this.keyUpHandler);
      delete this.keyUpHandler;
    }
  }
};
var ids_keyboard_mixin_default = IdsKeyboardMixin;

export {
  ids_keyboard_mixin_default
};
//# sourceMappingURL=ids-chunk-OHPMSJIR-full.js.map
