/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  getClosestContainerNode
} from "./ids-chunk-LQYSVESW-full.js";
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/mixins/ids-focus-capture-mixin/ids-focus-capture-mixin.ts
var FOCUS_CAPTURE_EVENTNAME = "keydown.focus-capture";
var IdsFocusCaptureMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.AUTO_FOCUS,
      attributes.CAPTURES_FOCUS,
      attributes.CYCLES_FOCUS,
      attributes.FOCUS_INLINE
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
    this.#removeFocusEvents();
    this.#focusableElementsInDocument = [];
  }
  /**
   * @property {boolean} capturesFocus If true, retains focus within the host component.
   * If focus is attempted on an element outside of this one, it will be "captured" and
   * placed on an element inside of this component.
   */
  #capturesFocus = false;
  set capturesFocus(val) {
    const currentVal = this.#capturesFocus;
    const newVal = stringToBool(val);
    if (currentVal !== newVal) {
      this.#capturesFocus = newVal;
      if (newVal) {
        this.setAttribute(attributes.CAPTURES_FOCUS, `${newVal}`);
      } else {
        this.removeAttribute(attributes.CAPTURES_FOCUS);
      }
      this.#updateFocusEvents();
    }
  }
  get capturesFocus() {
    return this.#capturesFocus;
  }
  /**
   * @property {boolean} cyclesFocus If true, while `capturesFocus` is true, cycles the focus
   * target element to the opposite end of the container.
   */
  #cyclesFocus = true;
  set cyclesFocus(val) {
    const currentVal = this.#cyclesFocus;
    const newVal = stringToBool(val);
    if (currentVal !== newVal) {
      this.#cyclesFocus = newVal;
      if (newVal) {
        this.setAttribute(attributes.CYCLES_FOCUS, `${newVal}`);
        this.gainFocus();
      } else {
        this.removeAttribute(attributes.CYCLES_FOCUS);
      }
    }
  }
  get cyclesFocus() {
    return this.#cyclesFocus;
  }
  /**
   * Connects the focus event to this component
   * @returns {void}
   */
  #attachFocusEvents() {
    const keydownEventHandler = (e) => {
      const isOnFirst = this.#hostNode.activeElement?.isEqualNode(this.firstFocusableElement);
      const isOnLast = this.#hostNode.activeElement?.isEqualNode(this.lastFocusableElement);
      switch (e.key) {
        case "Tab":
          if (isOnFirst && e.shiftKey) {
            e.preventDefault();
            requestAnimationFrame(() => {
              const targetElem = this.cyclesFocus ? this.lastFocusableElement : this.firstFocusableElement;
              targetElem.focus();
            });
          }
          if (isOnLast && !e.shiftKey) {
            e.preventDefault();
            requestAnimationFrame(() => {
              const targetElem = this.cyclesFocus ? this.firstFocusableElement : this.lastFocusableElement;
              targetElem.focus();
            });
          }
          break;
        default:
          break;
      }
      return true;
    };
    this.onEvent(FOCUS_CAPTURE_EVENTNAME, this.#hostNode, keydownEventHandler.bind(this));
  }
  /**
   * Disconnects the focus event from this component
   * @returns {void}
   */
  #removeFocusEvents() {
    this.offEvent(FOCUS_CAPTURE_EVENTNAME);
  }
  /**
   * Adds/Removes the focus event based on component state
   */
  #updateFocusEvents() {
    this.#removeFocusEvents();
    if (this.capturesFocus) {
      this.gainFocus();
      this.#attachFocusEvents();
    }
  }
  focusableSelectorList = [
    "button",
    "ids-button",
    "ids-dropdown",
    "ids-menu-button",
    "ids-modal-button",
    "ids-toggle-button",
    "[href]",
    "input",
    "ids-input",
    "ids-checkbox",
    "ids-radio",
    "ids-switch",
    "select",
    "textarea",
    "ids-textarea",
    '[tabindex]:not([tabindex="-1"]'
  ];
  get focusableSelectors() {
    return this.focusableSelectorList;
  }
  set focusableSelectors(val) {
    if (Array.isArray(val)) {
      this.focusableSelectorList = val;
    }
  }
  /**
   * @property {Array<HTMLElement>} focusable reference to all focusable elements on the document
   */
  #focusableElementsInDocument = [];
  /**
   * @readonly
   * @returns {Array<HTMLElement>} all possible focusable elements within Light DOM on the current page
   */
  get focusableElementsInDocument() {
    if (!this.#focusableElementsInDocument.length && this.focusableSelectors.length) this.refreshFocusableElements();
    return this.#focusableElementsInDocument;
  }
  refreshFocusableElements() {
    const selectorStr = this.focusableSelectors.join(", ");
    this.#focusableElementsInDocument = [...this.#hostNode.querySelectorAll(selectorStr)].filter((i) => !i.hasAttribute(attributes.HIDDEN));
  }
  /**
   * @readonly
   * @returns {Array<HTMLElement>} focusable elements inside of this WebComponent's Light DOM
   */
  get focusableElements() {
    if (this.focusInline) return this.focusableElementsInDocument;
    return this.focusableElementsInDocument.filter((i) => this.contains(i));
  }
  /**
   * @readonly
   * @returns {HTMLElement} the first focusable child element inside this component
   */
  get firstFocusableElement() {
    return this.focusableElements[0];
  }
  /**
   * @readonly
   * @returns {HTMLElement} the next focusable child element inside this component
   */
  get nextFocusableElement() {
    if (!this.focusableElements.length) {
      return void 0;
    }
    const thisIndex = this.focusableElementsInDocument.indexOf(this.#hostNode.activeElement);
    const nextElem = this.focusableElementsInDocument[thisIndex + 1];
    if (!this.contains(nextElem) && this.cyclesFocus) {
      return this.firstFocusableElement;
    }
    return nextElem;
  }
  /**
   * @readonly
   * @returns {HTMLElement} the previous focusable child element inside this component
   */
  get previousFocusableElement() {
    if (!this.focusableElements.length) {
      return void 0;
    }
    const thisIndex = this.focusableElementsInDocument.indexOf(this.#hostNode.activeElement);
    const prevElem = this.focusableElementsInDocument[thisIndex - 1];
    if (!this.contains(prevElem) && this.cyclesFocus) {
      return this.lastFocusableElement;
    }
    return prevElem;
  }
  /**
   * @readonly
   * @returns {HTMLElement} the last focusable child element inside this component
   */
  get lastFocusableElement() {
    return this.focusableElements.slice(-1)[0];
  }
  /**
   * Focuses the first-possible element within the Modal
   * @param {number|string} index the desired focusable element index to use
   * @returns {void}
   */
  setFocus(index = 0) {
    const focusable = this.focusableElements;
    const focusedEl = this.#hostNode.activeElement;
    const focusedIndex = this.focusableElements.indexOf(focusedEl);
    let safeIndex = 0;
    if (focusable.length) {
      switch (index) {
        case "last":
          safeIndex = focusable.length - 1;
          break;
        case "first":
        case "":
          break;
        default:
          safeIndex = typeof index === "string" ? parseInt(index) : index;
          break;
      }
      requestAnimationFrame(() => {
        focusable[safeIndex]?.focus();
      });
    }
    return focusedIndex === safeIndex;
  }
  /**
   * Retrieves focus from elements outside of this one, and attaches
   * focus to a specified element index.
   * @param {number|string} index the desired focusable element index to use
   * @returns {void}
   */
  gainFocus(index = 0) {
    if (!this.contains(this.#hostNode.activeElement) && this.autoFocus) {
      this.setFocus(index);
    }
  }
  /*
   * The top-level node responsible for hosting focus.
   * If focusInline is true, returns this component's shadowRoot (or document as fallback).
   * Otherwise returns the closest container node (document or parent shadow root).
   */
  get #hostNode() {
    if (this.focusInline) {
      return this.shadowRoot || document;
    }
    return getClosestContainerNode(this);
  }
  /**
   * @param {boolean | string} val true if focus detection should only occur within this component's shadow root
   */
  set focusInline(val) {
    const newValue = stringToBool(val);
    if (newValue) {
      this.setAttribute(attributes.FOCUS_INLINE, "true");
    } else {
      this.removeAttribute(attributes.FOCUS_INLINE);
    }
  }
  /**
   * @returns {boolean} true if this component should only capture focus within its shadow root
   */
  get focusInline() {
    return this.hasAttribute(attributes.FOCUS_INLINE);
  }
  /**
   * Whether or not to focus on the first focusable element when the component is shown
   * @param {string | boolean | null} val value to be set as auto-focus attribute converted to boolean
   */
  set autoFocus(val) {
    const boolVal = stringToBool(val);
    this.setAttribute(attributes.AUTO_FOCUS, String(boolVal));
  }
  /**
   * auto-focus attribute, default is true
   * @returns {boolean} autoFocus param converted to boolean from attribute value
   */
  get autoFocus() {
    const attrVal = this.getAttribute(attributes.AUTO_FOCUS);
    if (attrVal) {
      return stringToBool(attrVal);
    }
    return true;
  }
};
var ids_focus_capture_mixin_default = IdsFocusCaptureMixin;

export {
  ids_focus_capture_mixin_default
};
//# sourceMappingURL=ids-chunk-ORDSAQSV-full.js.map
