/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  IdsInput
} from "./ids-chunk-WLOZMPLJ-full.js";
import {
  isValidDate
} from "./ids-chunk-KNXP4KUS-full.js";
import {
  stringToBool
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-data-grid/ids-data-grid-editors.ts
var applyEditorSettings = (elem, settings) => {
  for (const setting in settings) {
    elem[setting] = settings[setting];
  }
};
var applyEditorValidation = (elem, validation) => {
  if (elem?.addValidationRule && validation) {
    validation.type = "error";
    elem?.addValidationRule?.(validation);
  }
};
var applyEditorPopupFocus = async (editor) => {
  const autoOpen = editor.clickEvent?.target?.classList?.contains("editor-cell-icon");
  if (autoOpen) {
    await editor.popup?.show();
    editor.popup?.focus();
  } else {
    editor.input?.focus();
  }
};
var applyEditorEndCellEdit = (cell, e) => {
  if (e.code === "Escape") {
    e.stopImmediatePropagation();
    e.stopPropagation();
    e.preventDefault();
    cell?.cancelCellEdit();
    cell?.focus();
  }
};
var InputEditor = class {
  /** The type of editor (i.e. input, dropdown, checkbox ect) */
  type = "input";
  /** Holds the Editor */
  input;
  /**
   * Create an input and set the value and focus states
   * @param {IdsDataGridCell} cell the cell element
   */
  init(cell) {
    const isInline = cell?.column.editor?.inline;
    this.input = document.createElement("ids-input");
    this.input.colorVariant = isInline ? "in-cell" : "borderless";
    this.input.size = "full";
    this.input.fieldHeight = String(cell?.dataGrid?.rowHeight) === "xxs" ? `xs` : String(cell?.dataGrid?.rowHeight);
    this.input.labelState = "collapsed";
    const value = cell?.innerText;
    cell.innerHTML = "";
    cell?.appendChild(this.input);
    this.input.addEventListener("keydown", (e) => applyEditorEndCellEdit(cell, e));
    this.input.value = value;
    if (this.input instanceof IdsInput && cell) {
      if (!isInline) this.input.shadowRoot?.querySelector("input")?.style.setProperty("width", `${cell.offsetWidth - 5}px`);
      applyEditorSettings(this.input, cell?.column.editor?.editorSettings);
      applyEditorValidation(this.input, cell?.column.editor?.editorValidation);
    }
    this.input.focus();
  }
  /* Transform the value */
  save() {
    return { value: this.input?.value };
  }
  /* Destroy the editor */
  destroy() {
    this.input = void 0;
  }
  value() {
    return this.input?.value ?? "";
  }
  change(newValue) {
    if (this.input) this.input.value = String(newValue);
  }
};
var CheckboxEditor = class {
  /** The type of editor (i.e. input, dropdown, checkbox ect) */
  type = "checkbox";
  /** Holds the Editor */
  input;
  /** MouseEvent if click was used to edit */
  clickEvent;
  /**
   * Create an input and set the value and focus states
   * @param {IdsDataGridCell} cell the cell element
   */
  init(cell) {
    this.input = document.createElement("ids-checkbox");
    const value = stringToBool(cell?.querySelector("[aria-checked]")?.getAttribute("aria-checked"));
    cell.innerHTML = "";
    if (!this.clickEvent) this.input.noAnimation = true;
    this.input.checked = this.clickEvent ? !value : value;
    this.input.isDirty = !!this.clickEvent;
    cell?.appendChild(this.input);
    requestAnimationFrame(() => {
      cell?.endCellEdit();
      cell?.focus();
    });
  }
  /* Transform the value */
  save() {
    return { value: this.input?.checked };
  }
  /* Destroy the editor */
  destroy() {
    this.input?.offEvent("keydown");
    this.input = void 0;
  }
  value() {
    return !!this.input?.checked;
  }
  change(newValue) {
    if (this.input) this.input.checked = Boolean(newValue);
  }
};
var DropdownEditor = class {
  /** The type of editor (i.e. input, dropdown, checkbox ect) */
  type = "dropdown";
  /** Holds the Editor */
  input;
  /** Holds the separate Dropdown List */
  list;
  /** Cache cell reference */
  #cell;
  /** Cache dropdown value */
  #value;
  /** Callback reference to handle blur event propagation */
  #stopPropagationCb = this.stopPropagation.bind(this);
  /** MouseEvent if click was used to edit */
  clickEvent;
  async init(cell) {
    this.#value = cell?.querySelector("[data-value]")?.getAttribute("data-value") ?? cell?.value ?? null;
    const isInline = cell?.column.editor?.inline;
    const settings = { ...cell?.column?.editor?.editorSettings };
    const validation = { ...cell?.column?.editor?.editorValidation };
    let settingsOptions = settings?.options ?? [];
    this.input = document.createElement("ids-dropdown");
    this.list = document.createElement("ids-dropdown-list");
    if (cell?.column?.editor?.editorSettings?.source !== void 0 && cell?.column?.editor?.editorSettings?.source instanceof Function) {
      cell?.column?.editor?.editorSettings?.source().then(async (result) => {
        const newOptions = await result;
        settings.options = newOptions;
        settingsOptions = newOptions;
        this.input?.loadDataSet(settingsOptions);
      });
    }
    delete settings.options;
    applyEditorSettings(this.input, settings);
    if ([null, false, void 0].includes(this.input.typeahead)) {
      this.input.typeahead = false;
    }
    cell.innerHTML = "";
    cell.appendChild(this.input);
    this.input.addEventListener("keydown", (e) => applyEditorEndCellEdit(cell, e));
    cell.appendChild(this.list);
    cell.classList.add("is-focused");
    this.#cell = cell;
    this.list.insertAdjacentHTML("beforeend", "<ids-list-box></ids-list-box>");
    this.list.setAttribute("trigger-type", "custom");
    this.input.setAttribute("id", "ids-dropdown-active-cell");
    this.list.setAttribute("id", "ids-dropdown-list-active-cell");
    this.input.setAttribute("list", "#ids-dropdown-list-active-cell");
    const optionValues = settingsOptions.map((row) => String(row.value).toLowerCase());
    const defaultValue = cell?.defaultValue || this.#value;
    if (defaultValue && !optionValues.includes(defaultValue.toLowerCase())) {
      const [firstOption, ...remainingOptions] = settingsOptions;
      const defaultValueOption = { id: defaultValue, label: defaultValue, value: defaultValue };
      settingsOptions = [firstOption, defaultValueOption, ...remainingOptions];
    }
    this.input.loadDataSet(settingsOptions);
    this.list.configurePopup();
    this.list.setAttribute("slot", "menu-container");
    this.list.setAttribute("size", "full");
    this.list.setAttribute("attachment", ".ids-data-grid-wrapper");
    this.list.appendToTargetParent();
    if (this.list.popup) {
      this.list.popup.alignTarget = this.input;
      this.list.popup.onPlaceEnd = (popupRect, domElement) => {
        if (cell?.dataGrid?.rowHeight === "xxs") {
          domElement.style.top = `${parseInt(domElement.style.top) - 1}px`;
        }
        domElement.style.left = cell?.dataGrid?.localeAPI.isRTL() ? `${parseInt(domElement.style.left) - 2}px` : `${parseInt(domElement.style.left) + 0.5}px`;
        return popupRect;
      };
    }
    this.input.value = this.#value ?? "";
    this.input.size = "full";
    this.input.labelState = "collapsed";
    this.input.colorVariant = isInline ? "in-cell" : "borderless";
    this.input.fieldHeight = String(cell?.dataGrid?.rowHeight);
    const triggerField = this.input.container?.querySelector("ids-trigger-field");
    if (triggerField) {
      triggerField.focus();
      triggerField.colorVariant = isInline ? "in-cell" : "borderless";
    }
    if (validation) {
      applyEditorValidation(this.input.input, validation);
    }
    this.#attachEventListeners();
    if (this.clickEvent) {
      await this.input?.open(this.input.typeahead);
    }
  }
  /**
   * Overrides data grid cell's focusout event handling
   * @param {FocusEvent} evt focus event
   */
  stopPropagation(evt) {
    const tagName = evt.relatedTarget instanceof HTMLElement ? evt.relatedTarget.tagName : evt.relatedTarget;
    if (tagName === "IDS-DROPDOWN" || tagName === "IDS-LIST-BOX-OPTION") {
      evt.stopPropagation();
      evt.stopImmediatePropagation();
    }
  }
  /**
   * Attach dropdown event handlers
   */
  #attachEventListeners() {
    this.input?.onEvent("change", this.input, (evt) => {
      this.#value = evt.detail.value;
    });
    this.input?.onEvent("focusout", this.input, this.#stopPropagationCb);
    if (this.list) {
      this.list.onOutsideClick = (e) => {
        if (!e.composedPath().includes(this.list)) {
          this.input?.close();
        }
      };
      this.list.refreshTriggerEvents();
    }
    this.input?.onEvent("keydown", this.list, (e) => {
      const key = e.key;
      if (key === "Enter") {
        e.stopPropagation();
      }
    });
  }
  /* Save selected dropdown value */
  save() {
    return {
      value: this.input?.value,
      dirtyCheckValue: this.input?.input?.value
    };
  }
  /**
   * Destroy dropdown editor
   */
  destroy() {
    this.input?.offEvent("click");
    this.input?.offEvent("change");
    this.input?.offEvent("focusout", this.input, this.#stopPropagationCb);
    this.list?.offEvent("keydown");
    this.list?.remove();
    this.#value = void 0;
    this.#cell?.classList?.remove("is-focused");
    this.#cell = void 0;
  }
  value() {
    return this.input?.value ?? "";
  }
  change(newValue) {
    if (this.input) this.input.value = String(newValue);
  }
};
var DatePickerEditor = class {
  type = "datepicker";
  input;
  popup;
  clickEvent;
  #value;
  #displayValue = "";
  init(cell) {
    this.input = this.#buildDatePickerTriggerField(cell);
    this.popup = this.#buildDatePickerPopup(cell);
    this.#update(cell, cell.originalValue);
    cell.innerHTML = "";
    cell.appendChild(this.popup);
    cell.appendChild(this.input);
    this.input.addEventListener("keydown", (e) => applyEditorEndCellEdit(cell, e));
    this.input.value = this.#displayValue;
    this.popup?.syncDateAttributes(this.#value ?? /* @__PURE__ */ new Date());
    if (this.input) this.input.autoselect = cell?.column?.editor?.editorSettings?.autoselect || true;
    const validation = cell?.column.editor?.editorValidation;
    if (validation) {
      applyEditorValidation(this.input, validation);
    }
    if (this.popup) {
      const popup = this.popup;
      this.popup.value = this.#displayValue;
      this.popup.attachment = ".ids-data-grid-wrapper";
      this.popup.slot = "menu-container";
      this.popup.appendToTargetParent();
      if (this.popup.popup) {
        this.popup.popup.positionStyle = "fixed";
        this.popup.popup.popupOpenEventsTarget = document.body;
        this.popup.popup.onOutsideClick = (e) => {
          if (!e.composedPath().includes(popup)) {
            popup.hide();
          }
        };
      }
      this.popup.id = `${cell.column.field}-date-picker-popup`;
      this.popup.triggerType = "click";
      this.popup.triggerElem = `#${cell.column.field}-date-picker-btn`;
      this.popup.target = `#${cell.column.field}-date-picker`;
      this.popup.popup.align = "bottom, right";
      this.popup.popup.arrowTarget = `#${cell.column.field}-date-picker-btn`;
      this.popup.popup.y = 16;
      this.popup.refreshTriggerEvents();
      applyEditorPopupFocus(this);
    }
    this.#attachEventListeners(cell);
  }
  #buildDatePickerTriggerField(cell) {
    const component = document.createElement("ids-trigger-field");
    applyEditorSettings(component, cell?.column.editor?.editorSettings);
    component.id = `${cell.column.field}-date-picker`;
    component.fieldHeight = String(cell?.dataGrid?.rowHeight) === "xxs" ? `xs` : String(cell?.dataGrid?.rowHeight);
    component.labelState = "collapsed";
    component.colorVariant = "borderless";
    component.size = "full";
    component.mask = true;
    component.insertAdjacentHTML(
      "beforeend",
      `<ids-trigger-button
        class="ids-trigger-field-slot-trigger-end"
        id="${cell.column.field}-date-picker-btn"
        slot="trigger-end"
        icon="calendar"></ids-trigger-button>`
    );
    return component;
  }
  #buildDatePickerPopup(cell) {
    const component = document.createElement("ids-date-picker-popup");
    applyEditorSettings(component, cell?.column.editor?.editorSettings);
    return component;
  }
  #update(cell, dateString) {
    const inputDate = cell?.dataGrid.localeAPI.parseDate(
      dateString,
      { dateFormat: cell?.column?.editor?.editorSettings?.format || void 0 }
    );
    if (!dateString || !isValidDate(inputDate)) {
      this.#displayValue = dateString;
      this.#value = void 0;
      return;
    }
    if (this.#value instanceof Date) {
      this.#value.setFullYear(inputDate.getFullYear());
      this.#value.setMonth(inputDate.getMonth());
      this.#value.setDate(inputDate.getDate());
    } else {
      this.#value = inputDate;
    }
    this.#displayValue = cell.dataGrid.localeAPI.formatDate(this.#value, cell.column?.editor?.editorSettings);
  }
  #stopPropagation(evt) {
    const isOpen = this.input?.popup?.hidden === false;
    if (isOpen) evt.stopImmediatePropagation();
  }
  #attachEventListeners(cell) {
    const focusOutHandler = (evt) => this.#stopPropagation(evt);
    this.input?.onEvent("focusout", this.input, focusOutHandler, { capture: true });
    this.popup?.onEvent("hide", this.popup, () => {
      if (cell.contains(cell.dataGrid.shadowRoot.activeElement)) return;
      if (!cell.dataGrid.contains(document.activeElement)) return;
      if (!cell.dataGrid.shadowRoot.contains(document.activeElement)) return;
      cell?.focus();
    });
  }
  save(cell) {
    this.#update(cell, cell?.value);
    return {
      value: this.#value?.toISOString() ?? "",
      dirtyCheckValue: this.#displayValue
    };
  }
  destroy() {
    this.input?.offEvent("focusout");
    this.input?.offEvent("outsideclick.datepicker");
    this.popup?.offEvent("hide");
    this.popup?.remove();
    this.#value = void 0;
    this.#displayValue = "";
  }
  value() {
    return this.input?.input?.value ?? "";
  }
  change(newValue) {
    if (this.input?.input) this.input.input.value = String(newValue);
  }
};
var TimePickerEditor = class {
  type = "timepicker";
  input;
  popup;
  clickEvent;
  #originalDate;
  init(cell) {
    this.input = this.#buildTimePickerTriggerField(cell);
    this.popup = this.#buildTimePickerPopup(cell);
    const dateString = cell.originalValue ?? "";
    const date = cell.dataGrid.localeAPI.parseDate(dateString, void 0, true);
    const isValid = isValidDate(date);
    this.#originalDate = isValid ? date : void 0;
    this.input.value = isValid ? cell.dataGrid.localeAPI.formatDate(this.#originalDate, { pattern: this.input.format }) : "";
    cell.innerHTML = "";
    cell.appendChild(this.popup);
    cell.appendChild(this.input);
    this.input.addEventListener("keydown", (e) => applyEditorEndCellEdit(cell, e));
    this.input.autoselect = cell?.column?.editor?.editorSettings?.autoselect || true;
    if (this.popup) {
      const popup = this.popup;
      this.popup.attachment = ".ids-data-grid-wrapper";
      this.popup.slot = "menu-container";
      this.popup.appendToTargetParent();
      if (this.popup.popup) {
        this.popup.popup.positionStyle = "fixed";
        this.popup.popup.popupOpenEventsTarget = document.body;
        this.popup.popup.onOutsideClick = async (e) => {
          if (!e.composedPath().includes(popup)) {
            await popup.hide();
          }
        };
      }
      this.popup.id = `${cell.column.field}-time-picker-popup`;
      this.popup.triggerType = "click";
      this.popup.triggerElem = `#${cell.column.field}-time-picker-btn`;
      this.popup.target = `#${cell.column.field}-time-picker`;
      this.popup.popup.align = "bottom, right";
      this.popup.popup.arrowTarget = `#${cell.column.field}-time-picker-btn`;
      this.popup.popup.y = 16;
      this.popup.refreshTriggerEvents();
      if (this.#originalDate) {
        const hours = this.#originalDate.getHours();
        this.popup.hours = hours > 11 ? hours - 12 : hours;
        this.popup.minutes = this.#originalDate.getMinutes();
        this.popup.seconds = this.#originalDate.getSeconds();
        this.popup.period = hours > 11 ? "PM" : "AM";
      }
      applyEditorPopupFocus(this);
    }
    this.#attachEventListeners(cell);
  }
  #buildTimePickerTriggerField(cell) {
    const component = document.createElement("ids-trigger-field");
    applyEditorSettings(component, cell?.column.editor?.editorSettings);
    component.id = `${cell.column.field}-time-picker`;
    component.fieldHeight = String(cell?.dataGrid?.rowHeight) === "xxs" ? `xs` : String(cell?.dataGrid?.rowHeight);
    component.labelState = "collapsed";
    component.colorVariant = "borderless";
    component.size = "full";
    component.mask = true;
    component.insertAdjacentHTML(
      "beforeend",
      `<ids-trigger-button
        class="ids-trigger-field-slot-trigger-end"
        id="${cell.column.field}-time-picker-btn"
        slot="trigger-end"
        icon="clock"></ids-trigger-button>`
    );
    return component;
  }
  #buildTimePickerPopup(cell) {
    const popup = document.createElement("ids-time-picker-popup");
    applyEditorSettings(popup, cell?.column.editor?.editorSettings);
    return popup;
  }
  #attachEventListeners(cell) {
    this.popup?.onEvent("hide", this.popup, () => {
      if (cell.contains(cell.dataGrid.shadowRoot.activeElement)) return;
      cell?.focus();
    });
  }
  save(cell) {
    let date;
    const inputValue = this.input.value;
    if (inputValue) {
      date = cell.dataGrid.localeAPI.parseDate(inputValue, { pattern: this.input.format }, true);
      if (this.#originalDate && (this.#originalDate.getMonth() !== date?.getMonth() || this.#originalDate.getFullYear() !== date?.getFullYear() || this.#originalDate.getDate() !== date?.getDate())) {
        date?.setMonth(this.#originalDate.getMonth());
        date?.setFullYear(this.#originalDate.getFullYear());
        date?.setDate(this.#originalDate.getDate());
      }
    }
    return {
      value: date && isValidDate(date) ? date?.toISOString() : void 0,
      dirtyCheckValue: inputValue
    };
  }
  destroy() {
    this.input?.offEvent("focusout");
    this.input?.detachAllListeners();
    this.input?.remove();
    this.popup?.offEvent("hide");
    this.popup?.detachAllListeners();
    this.popup?.remove();
    this.#originalDate = void 0;
  }
  value() {
    return this.input?.value ?? "";
  }
  change(newValue) {
    if (this.input) this.input.value = String(newValue);
  }
};
var TreeEditor = class extends InputEditor {
  expandButton;
  fieldContainer;
  /**
   * Adds extra button element for mimicking the tree formatter's display
   * @param {IdsDataGridCell} cell the cell element
   */
  init(cell) {
    super.init(cell);
    const buttonHTML = this.#isExpandable(cell) ? `<ids-button class="expand-button" disabled="true">
      <ids-icon icon="plusminus-folder-${this.#isExpanded(cell) ? "open" : "closed"}"></ids-icon>
    </ids-button>` : "";
    cell.insertAdjacentHTML("afterbegin", `<span class="ids-data-grid-tree-container">
      ${buttonHTML}
      <span class="ids-data-grid-tree-field-container"></span>
    </span>`);
    this.expandButton = cell.querySelector(".expand-button");
    this.fieldContainer = cell.querySelector(".ids-data-grid-tree-field-container");
    this.fieldContainer.appendChild(this.input);
  }
  #isExpanded(cell) {
    return cell.dataGrid.rows[cell.rowIndex].getAttribute("aria-expanded") === "true";
  }
  #isExpandable(cell) {
    return cell.dataGrid.data[cell.rowIndex].childCount;
  }
  destroy() {
    super.destroy();
    this.expandButton?.remove();
    this.fieldContainer?.remove();
    this.expandButton = void 0;
    this.fieldContainer = void 0;
  }
};
var LookupEditor = class {
  type = "lookup";
  input;
  popup;
  clickEvent;
  /**
   * Create an input and set the value and focus states
   * @param {IdsDataGridCell} cell the cell element
   */
  init(cell) {
    const isInline = cell?.column.editor?.inline;
    this.input = document.createElement("ids-lookup");
    this.input.size = isInline ? "full" : "";
    this.input.clearable = true;
    this.input.labelState = "collapsed";
    const value = cell?.innerText ?? "";
    cell.innerHTML = "";
    cell?.appendChild(this.input);
    this.input.addEventListener("keydown", (e) => applyEditorEndCellEdit(cell, e));
    this.input.value = value;
    this.popup = this.input.modal ?? void 0;
    applyEditorSettings(this.input, { ...cell?.column.editor?.editorSettings });
    applyEditorValidation(this.input?.input, cell?.column.editor?.editorValidation);
    applyEditorPopupFocus(this);
    if (this.input?.triggerField) {
      this.input.triggerField.labelState = "collapsed";
      this.input.triggerField.colorVariant = isInline ? "in-cell" : "borderless";
      this.input.triggerField.focus();
    }
    const rowHeight = String(cell?.dataGrid?.rowHeight);
    this.input.fieldHeight = rowHeight === "xxs" ? `xs` : rowHeight;
    this.input.triggerField?.toggleAttribute(attributes.NO_MARGINS, rowHeight !== "xxs");
    this.input.triggerField?.clearableButton?.toggleAttribute(attributes.NO_MARGINS, rowHeight !== "xxs");
    this.input.triggerButton?.toggleAttribute(attributes.NO_MARGINS, rowHeight !== "xxs");
  }
  value() {
    return this.input?.value ?? "";
  }
  change(newValue) {
    if (this.input) this.input.value = String(newValue);
  }
  /* Save selected dropdown value */
  save() {
    return {
      value: this.input?.value,
      dirtyCheckValue: this.input?.input?.value
    };
  }
  /* Destroy the editor */
  destroy() {
    this.input?.offEvent("keydown");
    this.input?.offEvent("change");
    this.input = void 0;
  }
};
var editors = [];
editors.push({
  type: "input",
  editor: new InputEditor()
});
editors.push({
  type: "checkbox",
  editor: new CheckboxEditor()
});
editors.push({
  type: "dropdown",
  editor: new DropdownEditor()
});
editors.push({
  type: "datepicker",
  editor: new DatePickerEditor()
});
editors.push({
  type: "timepicker",
  editor: new TimePickerEditor()
});
editors.push({
  type: "tree",
  editor: new TreeEditor()
});
editors.push({
  type: "lookup",
  editor: new LookupEditor()
});

export {
  InputEditor,
  CheckboxEditor,
  DropdownEditor,
  DatePickerEditor,
  TimePickerEditor,
  TreeEditor,
  LookupEditor,
  editors
};
//# sourceMappingURL=ids-chunk-PMST3V5V-full.js.map
