/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  eventPath,
  findInPath
} from "./ids-chunk-6UX53JJC-full.js";
import {
  debounce
} from "./ids-chunk-BMFYSQO7-full.js";
import {
  sanitizeHTML
} from "./ids-chunk-5K4YUTOH-full.js";
import {
  stringToBool,
  stringToNumber
} from "./ids-chunk-REOQKPVR-full.js";
import {
  attributes
} from "./ids-chunk-QQAXKC5H-full.js";

// src/components/ids-data-grid/ids-data-grid-tooltip-mixin.ts
var IdsDataGridTooltipMixin = (superclass) => class extends superclass {
  constructor(...args) {
    super(...args);
  }
  static get attributes() {
    return [
      ...superclass.attributes,
      attributes.SUPPRESS_TOOLTIPS
    ];
  }
  connectedCallback() {
    super.connectedCallback?.();
  }
  disconnectedCallback() {
    super.disconnectedCallback?.();
    this.#detachTooltip();
  }
  /**
   * Retrieves the current tooltip instance
   * @returns {HTMLElement} Reference to the component's tooltip object
   * @readonly
   */
  get tooltip() {
    return this.#tooltip;
  }
  /**
   * Set the tooltips on/off.
   * @param {string|boolean} value True as turn off
   */
  set suppressTooltips(value) {
    if (stringToBool(value)) {
      this.setAttribute(attributes.SUPPRESS_TOOLTIPS, "");
    } else {
      this.removeAttribute(attributes.SUPPRESS_TOOLTIPS);
    }
    this.setupTooltip();
  }
  get suppressTooltips() {
    return this.hasAttribute(attributes.SUPPRESS_TOOLTIPS);
  }
  /**
   * Single tooltip use with all grid elements
   * @private
   */
  #tooltip;
  /**
   * Types of tooltip as unique identifier
   * @private
   */
  #types = {
    BODY_CELL: "body-cell",
    FILTER_BUTTON: "filter-button",
    HEADER_TITLE: "header-title",
    HEADER_ICON: "header-icon"
  };
  /**
   * Setup tooltip
   * @private
   * @returns {void}
   */
  setupTooltip() {
    if (this.suppressTooltips) this.#detachTooltip();
    else this.#attachTooltip();
  }
  /**
   * Handle tooltip
   * @private
   * @param {MouseEvent} e The event
   */
  async #handleTooltip(e) {
    const path = eventPath(e);
    this.#hideTooltip();
    if (findInPath(path, ".ids-data-grid-body") && findInPath(path, '[role="gridcell"]')) {
      await this.#tooltipBodyCell(path);
      return;
    }
    if (findInPath(path, ".ids-data-grid-header-text") || findInPath(path, ".ids-data-grid-header-icon")) {
      await this.#tooltipHeaderTitleOrIcon(path);
      return;
    }
    if (findInPath(path, ".ids-data-grid-header-cell-filter-wrapper") && findInPath(path, "ids-menu-button")) {
      await this.#tooltipFilterButton(path);
    }
  }
  /**
   * Handle tooltip for body cell
   * @private
   * @param  {HTMLElement[]} path List of path element.
   */
  async #tooltipBodyCell(path) {
    const ambientGrid = this;
    const cellEl = findInPath(path, '[role="gridcell"]');
    const link = findInPath(path, "ids-hyperlink");
    const textEllipsis = link ? cellEl : cellEl.querySelector(".text-ellipsis");
    const rowIndex = stringToNumber(findInPath(path, '[role="row"]')?.getAttribute("data-index"));
    const columnIndex = stringToNumber(cellEl.getAttribute("aria-colindex")) - 1;
    const rowData = ambientGrid.data[rowIndex];
    const columnData = ambientGrid.columns[columnIndex];
    if (columnData?.tooltip || textEllipsis?.offsetWidth < textEllipsis?.scrollWidth) {
      const columnId = columnData.id;
      const fieldData = rowData[columnId];
      const text = (cellEl.textContent || "").trim();
      const callbackArgs = {
        type: this.#types.BODY_CELL,
        rowData,
        rowIndex,
        columnData,
        columnId,
        columnIndex,
        fieldData,
        text,
        grid: this
      };
      const content = await this.#tooltipContent({
        data: columnData,
        callbackArgs
      });
      if (typeof content === "string" && content !== "") {
        await this.#setTooltipCssPart({ data: columnData, callbackArgs });
        const defaultOptions = { placement: "top", x: 0, y: 0 };
        const parentCard = this.closest("ids-card");
        if (parentCard && rowIndex < 1) {
          defaultOptions.placement = "bottom";
        }
        const options = await this.#tooltipOptions({
          defaultOptions,
          data: columnData,
          callbackArgs
        });
        this.#showTooltip({
          target: cellEl,
          callbackArgs,
          content,
          options
        });
      }
    }
  }
  /**
   * Handle tooltip for header title or header icon
   * @private
   * @param  {HTMLElement[]} path List of path element.
   */
  async #tooltipHeaderTitleOrIcon(path) {
    const ambientGrid = this;
    const cellEl = findInPath(path, '[role="columnheader"]');
    const titleEl = findInPath(path, ".ids-data-grid-header-text");
    const iconEl = findInPath(path, ".ids-data-grid-header-icon");
    const isHeaderIcon = !!iconEl;
    let data;
    let columnGroupId;
    let columnGroupData;
    let columnId;
    let columnIndex;
    let columnData;
    let isCustomTooltip = false;
    const isHeaderGroup = cellEl.hasAttribute("column-group-id");
    if (isHeaderGroup) {
      columnGroupId = cellEl.getAttribute("column-group-id");
      columnGroupData = ambientGrid.columnGroupDataById(columnGroupId);
      data = columnGroupData;
    } else {
      columnId = cellEl.getAttribute("column-id");
      columnIndex = ambientGrid.columnIdxById(columnId);
      columnData = ambientGrid.columns[columnIndex];
      data = columnData;
    }
    if (isHeaderIcon) isCustomTooltip = !!data?.headerIconTooltip;
    else isCustomTooltip = !!(data?.headerTooltip ?? data?.tooltip);
    const checkboxLabel = titleEl?.querySelector(".ids-checkbox label .label-text");
    const hasEllipsis = checkboxLabel ? checkboxLabel?.offsetWidth < checkboxLabel?.scrollWidth : titleEl?.offsetWidth < titleEl?.scrollWidth;
    if (isCustomTooltip || (isHeaderIcon || hasEllipsis)) {
      const iconText = isHeaderIcon ? iconEl.getAttribute("data-headericontooltip") : null;
      let callbackArgs = {
        grid: this,
        text: (iconText || titleEl.textContent || "").trim(),
        type: isHeaderIcon ? this.#types.HEADER_ICON : this.#types.HEADER_TITLE,
        isHeaderGroup,
        headerTooltip: data?.headerTooltip,
        hasEllipsis
      };
      if (isHeaderGroup) {
        callbackArgs = {
          ...callbackArgs,
          columnGroupId,
          columnGroupData,
          rowIndex: 0,
          columnGroupIndex: ambientGrid.columnGroupIdxById(columnGroupId)
        };
      } else {
        callbackArgs = {
          ...callbackArgs,
          columnId,
          columnIndex,
          columnData,
          rowIndex: ambientGrid.columnGroups ? 1 : 0
        };
      }
      const content = await this.#tooltipContent({
        callbackArgs,
        data
      });
      if (typeof content === "string" && content !== "") {
        await this.#setTooltipCssPart({ data, callbackArgs });
        const options = await this.#tooltipOptions({
          defaultOptions: { placement: "top", x: 0, y: isHeaderIcon ? 16 : 10 },
          callbackArgs,
          data
        });
        this.#showTooltip({
          target: isHeaderIcon ? iconEl : cellEl,
          callbackArgs,
          content,
          options
        });
      }
    }
  }
  /**
   * Handle tooltip for header filter button
   * @private
   * @param  {HTMLElement[]} path List of path element.
   */
  async #tooltipFilterButton(path) {
    const ambientGrid = this;
    const cellEl = findInPath(path, '[role="columnheader"]');
    const filterButton = findInPath(path, "ids-menu-button");
    if (filterButton) {
      const rowIndex = ambientGrid.columnGroups ? 1 : 0;
      const columnId = cellEl.getAttribute("column-id");
      const columnIndex = ambientGrid.columnIdxById(columnId);
      const columnData = ambientGrid.columns[columnIndex];
      const text = (filterButton.text || "").trim();
      const callbackArgs = {
        type: this.#types.FILTER_BUTTON,
        isFilterButton: true,
        rowIndex,
        columnData,
        columnIndex,
        columnId,
        text,
        grid: this
      };
      const content = await this.#tooltipContent({
        data: columnData,
        callbackArgs
      });
      if (typeof content === "string" && content !== "") {
        await this.#setTooltipCssPart({ data: columnData, callbackArgs });
        const options = await this.#tooltipOptions({
          defaultOptions: { placement: "bottom", x: 0, y: 6 },
          data: columnData,
          callbackArgs
        });
        this.#showTooltip({
          target: filterButton.dropdownIconEl,
          callbackArgs,
          content,
          options
        });
      }
    }
  }
  /**
   * Set tooltip css part.
   * @private
   * @param  {object} opt The options.
   */
  async #setTooltipCssPart(opt) {
    const { data, callbackArgs } = opt;
    const type = callbackArgs.type;
    let key = null;
    if (type === this.#types.BODY_CELL) key = "tooltipCssPart";
    if (type === this.#types.HEADER_TITLE) key = "headerTooltipCssPart";
    if (type === this.#types.HEADER_ICON) key = "headerIconTooltipCssPart";
    if (type === this.#types.FILTER_BUTTON) key = "filterButtonTooltipCssPart";
    let cssPart = "";
    if (key && data && typeof data[key] === "string") {
      cssPart = data[key];
    } else if (typeof data?.tooltipCssPart === "function") {
      cssPart = await data.tooltipCssPart(callbackArgs);
    }
    cssPart = sanitizeHTML(cssPart || "");
    let parts = [
      "tooltip-popup",
      "tooltip-arrow",
      "tooltip-arrow-top",
      "tooltip-arrow-right",
      "tooltip-arrow-bottom",
      "tooltip-arrow-left"
    ];
    if (cssPart !== "") parts = parts.map((p) => `${p}: ${cssPart}-${p}`);
    this.#tooltip?.setAttribute("exportparts", parts.join(", "));
  }
  /**
   * Get tooltip content to display.
   * @private
   * @param {object} opt The options.
   * @returns {void}
   */
  async #tooltipContent(opt) {
    const { data, callbackArgs } = opt;
    const type = callbackArgs.type;
    let key = null;
    let toFallbackContent = false;
    if (type === this.#types.BODY_CELL) key = "tooltip";
    if (type === this.#types.HEADER_TITLE) {
      key = "headerTooltip";
      toFallbackContent = !!callbackArgs.headerTooltip || callbackArgs.hasEllipsis;
    }
    if (type === this.#types.HEADER_ICON) key = "headerIconTooltip";
    if (type === this.#types.FILTER_BUTTON) {
      key = "filterButtonTooltip";
      toFallbackContent = true;
    }
    let content = "";
    if (key && data && typeof data[key] === "string") {
      content = data[key];
    } else if (typeof data?.tooltip === "function") {
      const callbackContent = await data.tooltip(callbackArgs);
      const fallbackContent = toFallbackContent ? callbackArgs.text : "";
      content = callbackContent || fallbackContent;
    } else {
      content = callbackArgs.text;
    }
    return sanitizeHTML(content || "");
  }
  /**
   * Get tooltip settings.
   * @private
   * @param {object} opt The options.
   * @returns {void}
   */
  async #tooltipOptions(opt) {
    const { data, callbackArgs, defaultOptions } = opt;
    const type = callbackArgs.type;
    let keys = {};
    if (type === this.#types.BODY_CELL) {
      keys = { placement: "placement", x: "x", y: "y" };
    } else if (type === this.#types.HEADER_TITLE) {
      keys = { placement: "headerPlacement", x: "headerX", y: "headerY" };
    } else if (type === this.#types.HEADER_ICON) {
      keys = { placement: "headerIconPlacement", x: "headerIconX", y: "headerIconY" };
    } else if (type === this.#types.FILTER_BUTTON) {
      keys = { placement: "filterButtonPlacement", x: "filterButtonX", y: "filterButtonY" };
    }
    const { placement, x, y } = keys;
    const options = { ...defaultOptions };
    if (data.tooltipOptions) {
      let userOptions = {};
      if (typeof data.tooltipOptions === "function") {
        userOptions = await data.tooltipOptions(callbackArgs);
      } else {
        userOptions[placement] = data.tooltipOptions[placement];
        userOptions[x] = data.tooltipOptions[x];
        userOptions[y] = data.tooltipOptions[y];
      }
      const adjustEdge = (v, isX) => {
        const val = parseInt(v, 10);
        if (!Number.isNaN(val)) options[isX ? "x" : "y"] = val;
      };
      adjustEdge(userOptions[x], true);
      adjustEdge(userOptions[y], false);
      if (/^(top|right|bottom|left)$/g.test(userOptions[placement] || "")) {
        options.placement = userOptions[placement];
      }
    }
    return options;
  }
  /**
   * Handle to show tooltip
   * @private
   * @param  {object} opt The options.
   * @returns {void}
   */
  #showTooltip(opt) {
    if (this.#mouseOut) return;
    const {
      target,
      content,
      options,
      callbackArgs
    } = opt;
    const args = { ...callbackArgs, content, options };
    if (!this.triggerVetoableEvent("beforetooltipshow", args)) {
      return;
    }
    if (this.#tooltip) {
      this.#tooltip.placement = options.placement;
      this.#tooltip.innerHTML = content;
      this.#tooltip.target = target;
      this.#tooltip.visible = true;
      this.#tooltip.popup.setPosition(options.x, options.y, true, true);
      this.triggerEvent("showtooltip", this, {
        bubbles: true,
        detail: { elem: this, args }
      });
    }
  }
  /**
   * Handle to hide tooltip
   * @private
   * @returns {void}
   */
  #hideTooltip() {
    this.#tooltip?.setAttribute("visible", "false");
    this.triggerEvent("hidetooltip", this, { bubbles: true, detail: { elem: this } });
  }
  #mouseOut = false;
  /**
   * Add tooltip and attach all tooltip events
   * @private
   * @returns {void}
   */
  #attachTooltip() {
    this.#tooltip = this.shadowRoot?.querySelector("ids-tooltip");
    if (!this.#tooltip) {
      this.shadowRoot?.querySelector('slot[name="tooltip"]')?.insertAdjacentHTML("beforeend", '<ids-tooltip id="tooltip" exportparts="tooltip-popup, tooltip-arrow"></ids-tooltip>');
      this.#tooltip = this.shadowRoot?.querySelector("ids-tooltip");
    }
    this.onEvent("mouseout.data-grid", this.container, debounce(async () => {
      this.#mouseOut = true;
      this.#hideTooltip();
    }, 250));
    this.onEvent("mouseover.data-grid", this.container, debounce(async (e) => {
      this.#mouseOut = false;
      await this.#handleTooltip(e);
    }, 250));
    this.onEvent("scroll.data-grid.tooltip-scroll", this.container, () => {
      this.#hideTooltip();
      this.offEvent("scroll.data-grid.tooltip-scroll", this.container);
    }, { capture: true, passive: true });
  }
  /**
   * Detach tooltip and all tooltip events
   * @private
   * @returns {void}
   */
  #detachTooltip() {
    this.offEvent("mouseover.data-grid", this.container);
    this.offEvent("mouseout.data-grid", this.container);
    this.offEvent("scroll.data-grid.tooltip-scroll", this.container);
    this.#tooltip?.remove();
    this.#tooltip = void 0;
  }
};
var ids_data_grid_tooltip_mixin_default = IdsDataGridTooltipMixin;

export {
  ids_data_grid_tooltip_mixin_default
};
//# sourceMappingURL=ids-chunk-RXVUH2JB-full.js.map
