/*!
 * Enterprise Web Components v1.14.1 (chunk/code split version all components)
 * Copyright (c) 2025 Infor
 */
import {
  ids_global_default
} from "./ids-chunk-BH5K2RGQ-full.js";
import {
  camelCase
} from "./ids-chunk-REOQKPVR-full.js";

// src/core/ids-element.ts
var IdsElement = class _IdsElement extends HTMLElement {
  constructor(args) {
    super();
    this.args = args;
    if (!args?.noShadowRoot) {
      this.#addBaseName();
      this.#appendHostCss();
      this.render();
    }
  }
  name = "";
  /** State object for current states */
  state = {};
  /** Nonce used for scripts, links */
  cachedNonce = "";
  /** Component's first child element */
  container = null;
  /** Styles Flag */
  hasStyles = false;
  /** Base connected call back */
  connectedCallback() {
    requestAnimationFrame(() => {
      this.mountedCallback();
    });
  }
  /** Lifecycle event for after loaded */
  mountedCallback() {
  }
  /**
   * Add a base name property
   * @private
   */
  #addBaseName() {
    this.name = this.nodeName?.toLowerCase();
  }
  /**
   * Handle Setting changes of the value has changed by calling the getter
   * in the extending class.
   * @param {string} name The property name
   * @param {string} oldValue The property old value
   * @param {string} newValue The property new value
   */
  attributeChangedCallback(name, oldValue, newValue) {
    if (oldValue === newValue) return;
    const self = this;
    const setter = {
      id: self.onIdChange,
      hidden: self.onHiddenChange
    }[name];
    if (typeof setter === "function") {
      setter.call(this, newValue);
      return;
    }
    const getAttributeName = (thisName) => {
      switch (thisName) {
        case "tabindex":
          return typeof this.tabIndex === "number" ? "tabIndex" : "tabindex";
        default:
          return camelCase(thisName);
      }
    };
    this[getAttributeName(name)] = newValue;
  }
  /**
   * Release events and cleanup, if implementing disconnectedCallback
   * in a component you can just call super.
   */
  disconnectedCallback() {
    this.cssStyles = null;
    this.popupOpenEventsTarget = null;
  }
  /**
   * Handle Changes on Properties, this is part of the web component spec.
   * @type {Array}
   */
  static get observedAttributes() {
    return this.attributes;
  }
  /**
   * @returns {Array<string>} this component's observable properties
   */
  static get attributes() {
    return [];
  }
  /**
   * Render the component using the defined template.
   * @param {string} force force to (re)render the component
   * @returns {object} The object for chaining.
   */
  render(force) {
    if ((!this.template || this.shadowRoot) && !force) {
      return this;
    }
    const templateHTML = this.template();
    if (!templateHTML) {
      return this;
    }
    const template = document.createElement("template");
    if (this.shadowRoot?.innerHTML) {
      for (const el of this.shadowRoot.children) {
        if (el.nodeName !== "STYLE") {
          el.remove();
        }
      }
    }
    if (!this.shadowRoot) {
      this.attachShadow({ mode: "open" });
    }
    this.appendStyles();
    template.innerHTML = templateHTML;
    this.shadowRoot?.appendChild(template.content.cloneNode(true));
    this.container = this.shadowRoot?.querySelector(`.${this.name}`);
    if (this.shadowRoot?.firstElementChild?.nodeName === "STYLE" && !this.container) {
      this.container = this.shadowRoot?.firstElementChild.nextElementSibling;
    }
    if (this.shadowRoot?.firstElementChild?.nodeName !== "STYLE" && !this.container) {
      this.container = this.shadowRoot?.firstElementChild;
    }
    return this;
  }
  /**
   * @returns {string} containing this component's HTML Template
   */
  template() {
    return "";
  }
  static cachedNonce = "";
  /**
   * @returns {string} gets the nonce from the meta tag
   */
  get nonce() {
    if (_IdsElement.cachedNonce !== "") {
      return _IdsElement.cachedNonce;
    }
    const documentElement = document;
    const elementWithNonce = this.closest("[ngCspNonce]");
    if (elementWithNonce) {
      const nonceValue = elementWithNonce.getAttribute("ngCspNonce");
      if (nonceValue) {
        _IdsElement.cachedNonce = nonceValue;
        return nonceValue;
      }
    }
    if (!documentElement.nonce) {
      const csp = document.querySelector('meta[http-equiv="Content-Security-Policy"]');
      if (csp) {
        let nonce = csp.getAttribute("content").match(/'nonce-(.*?)'/g);
        nonce = nonce ? nonce[0]?.replace("'nonce-", "").replace("'", "") : void 0;
        documentElement.nonce = nonce;
      }
    }
    _IdsElement.cachedNonce = documentElement.nonce || "0a59a005";
    return _IdsElement.cachedNonce;
  }
  /**
   * Append Styles if present
   * @private
   */
  appendStyles() {
    if (this.hasStyles || this.args?.noStyles) {
      return;
    }
    const style = document.createElement("style");
    style.textContent = this.cssStyles;
    if (this.nonce) style.setAttribute("nonce", this.nonce);
    this.shadowRoot?.appendChild(style);
    this.hasStyles = true;
  }
  /**
   * Append One host css
   * @private
   */
  #appendHostCss() {
    const win = window;
    if (!win.idsStylesAdded) {
      win.idsStylesAdded = true;
      this.theme = "default-light";
    }
  }
  /**
   * Append theme css
   * @param {string} theme name of the theme
   * @private
   */
  set theme(theme) {
    this.loadTheme(theme);
    document.body.querySelector("ids-theme-switcher")?.setAttribute("theme", theme);
  }
  lastTheme = "";
  /**
   * Get the theme and load it
   * @param {string} theme name of the theme
   */
  async loadTheme(theme) {
    if (ids_global_default.themeName === theme) return;
    ids_global_default.themeName = theme;
    const themeLoaded = ids_global_default.onThemeLoaded();
    document.querySelector("ids-container")?.setAttribute("hidden", "");
    const themeLink = document.querySelector('link[href*="ids-theme"]');
    if (themeLink) {
      const href = themeLink.getAttribute("href");
      const filename = href?.replace(/^.*[\\/]/, "") || "";
      themeLink.setAttribute("href", href?.replace(filename, `ids-theme-${theme}.css`) || "");
      setTimeout(() => {
        document.querySelector("ids-container")?.removeAttribute("hidden");
        themeLoaded.resolve();
      }, 150);
      return;
    }
    const isSelfManaged = document.querySelector("ids-theme-switcher[self-managed]");
    if (isSelfManaged) return;
    const baseHref = document.querySelector("base");
    const subUrl = baseHref?.getAttribute("href") || "/";
    let themePath = `..${subUrl}themes/ids-theme-${theme}.css`;
    if (ids_global_default?.themePath) {
      themePath = `${ids_global_default.themePath}ids-theme-${theme}.css`;
    }
    const response = await fetch(themePath, { cache: "default" });
    const themeStyles = await response.text();
    const head = document.head;
    const styleElem = document.querySelector("#ids-theme");
    const style = styleElem || document.createElement("style");
    const localeFonts = `
      html[lang='ar'] {--ids-font-family-default: var(--ids-font-family-ar), var(--ids-font-family-sans)}
      html[lang='he'] {--ids-font-family-default: var(--ids-font-family-he), var(--ids-font-family-sans)}
      html[lang='hi'] {--ids-font-family-default: var(--ids-font-family-hi), var(--ids-font-family-sans)}
      html[lang='ja'] {--ids-font-family-default: var(--ids-font-family-ja), var(--ids-font-family-sans)}
      html[lang='ko'] {--ids-font-family-default: var(--ids-font-family-ko), var(--ids-font-family-sans)}
      html[lang='th'] {--ids-font-family-default: var(--ids-font-family-th), var(--ids-font-family-sans)}
      html[lang='zh-Hans'] {--ids-font-family-default: var(--ids-font-family-zh-hans), var(--ids-font-family-sans)}
      html[lang='zh-Hant'] {--ids-font-family-default: var(--ids-font-family-zh-hant), var(--ids-font-family-sans)}
    `;
    const foucStyles = `
      ids-data-grid:not(:defined), ids-container:not(:defined) { opacity: 0; }
      ids-data-grid:defined, ids-container:defined { opacity: 1; }
    `;
    style.textContent = `${themeStyles}${localeFonts}${foucStyles}`;
    style.id = "ids-theme";
    if (this.nonce) style.setAttribute("nonce", this.nonce);
    if (!styleElem) {
      const titleElem = head.querySelector("title");
      if (titleElem) head.insertBefore(style, titleElem.nextElementSibling);
      else head.insertAdjacentHTML("beforeend", style);
    }
    this.loadLegacyTheme(theme);
    setTimeout(() => {
      document.querySelector("ids-container")?.removeAttribute("hidden");
      themeLoaded.resolve();
    }, 150);
  }
  /**
   * Switch the theme in 4.x components
   * @param {string} value The theme value for example: default-light
   */
  loadLegacyTheme(value) {
    let styleSheet = document.querySelector("#stylesheet");
    if (!styleSheet) styleSheet = document.querySelector("#sohoxi-stylesheet");
    if (!styleSheet) return;
    const href = styleSheet?.getAttribute("href");
    const mappedTheme = value.replace("default", "theme-new");
    if (!href) return;
    styleSheet?.setAttribute("href", href.replace("theme-new-light", mappedTheme).replace("theme-new-dark", mappedTheme).replace("theme-new-contrast", mappedTheme));
  }
};

export {
  IdsElement
};
//# sourceMappingURL=ids-chunk-UTR2KJV7-full.js.map
