import { type IdsColorValue } from '../../utils/ids-color-utils/ids-color-utils';
import type IdsDataGrid from './ids-data-grid';
import { IdsDataGridEditor } from './ids-data-grid-editors';
type IdsDateNumberOptions = Omit<Intl.DateTimeFormatOptions, 'localeMatcher'> & Omit<Intl.NumberFormatOptions, 'localeMatcher'> & {
    localeMatcher?: 'best fit' | 'lookup';
};
export interface IdsDataGridColumnFormatOptions extends IdsDateNumberOptions {
    style?: 'decimal' | 'currency' | 'percent' | 'unit' | any;
    locale?: string;
    /** Sets the group (thousands) seperator (to something outside the current locale) */
    group?: string;
    /** Sets Intl.NumberFormat option to use grouping  */
    useGrouping?: boolean;
    /** Sets the decimal seperator (to something outside the current locale) */
    decimal?: string;
    /** Date format to use for parsing ect */
    dateFormat?: string;
    /** Date format to use for parsing ect (more generic) */
    format?: string;
    /** legacy pattern for date formats */
    pattern?: string;
}
export interface IdsDataGridColumnGroup {
    id?: string;
    name?: string;
    colspan: number;
    /** Align the column text to either `left`, `center` or `right` */
    align?: string;
    /** Name of the header icon to use for formatters that support it */
    headerIcon?: string;
    /** Sets the header icon tooltip content */
    headerIconTooltip?: string;
}
export interface IdsDataGridTooltipCallback {
    columnId?: string;
    columnData?: any;
    columnIndex?: number;
    columnGroupId?: string;
    columnGroupData?: any;
    columnGroupIndex?: number;
    fieldData?: any;
    grid?: any;
    isHeaderGroup?: boolean;
    rowData?: any;
    rowIndex?: number;
    text?: string;
    type?: string;
}
export interface IdsDataGridDatePickerOptions {
    /** Option to show today or not (for date type filters)  */
    showToday?: boolean;
    /** Option to show cancel button or not (for date type filters)  */
    showCancel?: boolean;
    /** Option to show clear button or not (for date type filters)  */
    showClear?: boolean;
    /** First day of the week (for date type filters) */
    firstDayOfWeek?: number;
    /** Whether or not to show week numbers in the picklist (for date type filters) */
    showPicklistWeek?: boolean;
    /** Whether or not to show a list of months in the picklist (for date type filters) */
    showPicklistMonth?: boolean;
    /** Whether or not to show a list of years in the picklist (for date type filters) */
    showPicklistYear?: boolean;
    /** Show week numbers in front of each week of date picker (for date type filters) */
    showWeekNumbers?: boolean;
    /** Set whether or not to show current time in the time picker dropdowns */
    useCurrentTime?: boolean;
    /** Whether or not the component should be a range picker */
    useRange?: boolean;
}
export interface IdsDataGridTooltipOptions {
    placement?: 'top' | 'right' | 'bottom' | 'left';
    x?: number;
    y?: number;
    headerPlacement?: 'top' | 'right' | 'bottom' | 'left';
    headerX?: number;
    headerY?: number;
    headerIconPlacement?: 'top' | 'right' | 'bottom' | 'left';
    headerIconX?: number;
    headerIconY?: number;
    filterButtonPlacement?: 'top' | 'right' | 'bottom' | 'left';
    filterButtonX?: number;
    filterButtonY?: number;
}
export interface IdsDataGridEditorValidation {
    check: (input: any) => boolean;
    message: string;
    /** Validation Message Translation key */
    messageId?: string;
    id: string;
}
export interface IdsDataGridHeaderTextName {
    /** The header text for one line */
    text: string;
    /** The font style to use */
    emphasis?: 'normal' | 'subtle';
}
export interface IdsDataGridColumn {
    /** The columns unique id */
    id: string;
    /** The columns name */
    name?: string | Array<IdsDataGridHeaderTextName>;
    /** The columns field in the array to use */
    field?: string;
    /** The subsitute text to use (for hyperlink and some formatters) */
    text?: string | ((row: number, value: any, column: IdsDataGridColumn, index: Record<string, any>) => string | undefined);
    /** Max value of a range */
    max?: number;
    /** Mininum value of a range */
    min?: number;
    /** Adds expand/collapse icon to a column */
    showHeaderExpander?: boolean;
    /** Allow column sorting */
    sortable?: boolean;
    /** Allow column hide/show */
    hideable?: boolean;
    /** Allow column resizing */
    resizable?: boolean;
    /** Adds a drag indicator and allows the columns to be moved by dragging */
    reorderable?: boolean;
    /** Set a column width in pixel or percent */
    width?: number | string;
    /** When width is 'max-content', controls text measurement: true uses raw values, false (default) uses formatted values */
    useValueForSizing?: boolean;
    /** Set a min column width for resizing */
    minWidth?: number | string;
    /** Set a max column width for resizing */
    maxWidth?: number | string;
    /** Hide a column to be shown later */
    hidden?: boolean;
    /** Column Formatter Function */
    formatter?: (rowData: Record<string, unknown>, columnData: IdsDataGridColumn, index: number, parentDataGrid: IdsDataGrid) => string;
    /** Set the column to checked or unchecked (filtering) */
    isChecked?: (value: boolean) => boolean;
    /** If column is selected */
    isSelected?: boolean;
    /** Enable Href / Link Columns */
    href?: string | ((rowData: Record<string, unknown>, columnData: IdsDataGridColumn) => string);
    /** Fires for clickable formatters (like button) */
    click?: (rowData: Record<string, unknown>, columnData: IdsDataGridColumn, event: MouseEvent) => void;
    /** Fires for menuId formatters (like button) */
    selected?: (rowData: Record<string, unknown>, columnData: IdsDataGridColumn, event: CustomEvent) => void;
    /** Selector for menu id */
    menuId?: string;
    /** Get the color dynamically from a function or as text */
    color?: IdsColorValue | ((row: number, value: any, column: IdsDataGridColumn, index: Record<string, any>) => string | undefined);
    /** Suppress the ids-color tooltip */
    suppressColorTooltip?: boolean;
    /** Get the size dynamically from a function or as text */
    size?: string | ((row: number, value: any, column: IdsDataGridColumn, index: Record<string, any>) => string | undefined);
    /** Options to pass to the formatter */
    formatOptions?: IdsDataGridColumnFormatOptions;
    /** Column Filter to use */
    filterType?: string | any;
    /** Column Filter options to show */
    filterConditions?: any[];
    /** Options to pass to the filter */
    filterOptions?: {
        /** The columns unique id */
        columnId?: string;
        /** Define a custom id for the inputs */
        customId?: string | ((columnData: IdsDataGridColumn) => string);
        /** The label in the filter */
        label?: string;
        /** The size of the input field */
        size?: string;
        /** The filter type */
        type?: string;
        /** Disable the filter */
        disabled?: boolean;
        /** Make the filter readonly */
        readonly?: boolean;
        /** Date formation to show  (for date type filters) */
        format?: string;
        /** Placeholder to show for empty inputs */
        placeholder?: string;
        /** The interval between minutes (for time type filters) */
        minuteInterval?: number;
        /** The interval between seconds (for time type filters) */
        secondInterval?: number;
        /** Sets the auto select attribute (for time type filters) */
        autoselect?: boolean;
        /** Sets the auto update attribute (for time type filters) */
        autoupdate?: boolean;
        /** If the filter type is "contents" lets you set a blank string to a text value (matched by ID) */
        notFilteredItem?: {
            value: string;
            label: string;
        };
        /** For filter type input, sets the text to all upper case when typed */
        uppercase?: boolean;
        /** For filter type input, sets the text max lenght when typed */
        maxlength?: number;
        /**  Adds the autocomplete attribute to the input element allowing for browser autocomplete */
        browserAutocomplete?: string;
    } & IdsDataGridDatePickerOptions;
    /** Lets you make a dynamic filter function */
    filterFunction?: any;
    /** True if the row is selected */
    rowSelected?: boolean;
    /** True if the row is activated */
    rowActivated?: boolean;
    /** Sets a custom css-part for styling the cell */
    cssPart?: string | ((args: object) => string);
    /** Sets a custom css-part for styling cell when it's selected */
    cellSelectedCssPart?: string | ((args: object) => string);
    /** Pass the type option to formatters that support it */
    type?: string;
    /** Disable the column with a boolean or a dynamic function */
    disabled?: boolean | ((row: number, value: any, col: IdsDataGridColumn, item: Record<string, any>) => boolean);
    /** Make the column readonly with a boolean or a dynamic function */
    readonly?: boolean | ((row: number, value: any, col: IdsDataGridColumn, item: Record<string, any>) => boolean);
    /** Column will not be styled as readonly when the readonly property is true */
    excludeReadonlyStyling?: boolean;
    /** Name of the icon too use for formatters that support it */
    icon?: string | ((row: number, value: any, column: IdsDataGridColumn, index: Record<string, any>) => string | undefined);
    /** Name of the header icon */
    headerIcon?: string;
    /** Align the column to either `left`, `center` or `right` */
    align?: string;
    /** Separately align the filter row contents to either `left`, `center`, or `right` */
    filterAlign?: string;
    /** Seperately align the header to either `left`, `center` or `right` */
    headerAlign?: string;
    /** Freeze the columns to either the `left` or `right` sides */
    frozen?: string;
    /** If a tree or expandable row will set the state of the row */
    rowExpanded?: boolean;
    /** Sets the tooltip options */
    tooltipOptions?: IdsDataGridTooltipOptions | ((options: IdsDataGridTooltipCallback) => IdsDataGridTooltipOptions);
    /** Sets the tooltip content */
    tooltip?: string | ((options: IdsDataGridTooltipCallback) => string | Promise<string>);
    /** Sets the header tooltip content */
    headerTooltip?: string;
    /** Sets the header icon tooltip content */
    headerIconTooltip?: string;
    /** Sets the header filter button tooltip content */
    filterButtonTooltip?: string;
    /** Sets the tooltip css part */
    tooltipCssPart?: string | ((options: IdsDataGridTooltipCallback) => string);
    /** Sets the header tooltip css part */
    headerTooltipCssPart?: string;
    /** Sets the header icon tooltip css part */
    headerIconTooltipCssPart?: string;
    /** Sets the header filter button tooltip css part */
    filterButtonTooltipCssPart?: string;
    /** Sets the hyperlink behavior. options: 'default' | 'no-select' | 'de-select' | 'none' */
    hyperlinkBehavior?: string;
    /** Setup an editor */
    editor?: {
        type: 'input' | 'date' | 'time' | 'checkbox' | 'dropdown' | 'datepicker' | 'timepicker' | 'tree' | 'lookup';
        inline?: boolean;
        /** If true, the editor icon will always be visible */
        showEditorIcons?: boolean;
        editor?: IdsDataGridEditor;
        editorSettings?: Record<string, unknown>;
        editorValidation?: IdsDataGridEditorValidation;
    };
    /** If a true will set the text to uppercase */
    uppercase?: boolean | 'true' | ((type: 'body-cell' | 'header-cell', col: IdsDataGridColumn, index?: number, value?: any, item?: Record<string, any>) => boolean);
    /** If set to false the column will not be exported in exportToExcel functionality */
    exportable?: boolean;
}
export {};
